/****************************************************************************
** Meta object code from reading C++ file 'device.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/device.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'device.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt6DeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::Device::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt6DeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::Device",
        "deviceRemoved",
        "",
        "DevicePtr",
        "device",
        "deviceChanged",
        "gattServiceAdded",
        "GattServiceRemotePtr",
        "service",
        "gattServicesChanged",
        "QList<GattServiceRemotePtr>",
        "services",
        "gattServiceRemoved",
        "gattServiceChanged",
        "nameChanged",
        "name",
        "addressChanged",
        "address",
        "friendlyNameChanged",
        "friendlyName",
        "remoteNameChanged",
        "remoteName",
        "deviceClassChanged",
        "deviceClass",
        "typeChanged",
        "Type",
        "type",
        "appearanceChanged",
        "appearance",
        "iconChanged",
        "icon",
        "pairedChanged",
        "paired",
        "trustedChanged",
        "trusted",
        "blockedChanged",
        "blocked",
        "legacyPairingChanged",
        "legacyPairing",
        "rssiChanged",
        "rssi",
        "manufacturerDataChanged",
        "ManData",
        "man",
        "servicesResolvedChanged",
        "servicesResolved",
        "connectedChanged",
        "connected",
        "uuidsChanged",
        "uuids",
        "modaliasChanged",
        "modalias",
        "serviceDataChanged",
        "QHash<QString,QByteArray>",
        "serviceData",
        "batteryChanged",
        "BatteryPtr",
        "battery",
        "inputChanged",
        "InputPtr",
        "input",
        "mediaPlayerChanged",
        "MediaPlayerPtr",
        "mediaPlayer",
        "mediaTransportChanged",
        "MediaTransportPtr",
        "mediaTransport",
        "connectToDevice",
        "PendingCall*",
        "disconnectFromDevice",
        "connectProfile",
        "uuid",
        "disconnectProfile",
        "pair",
        "cancelPairing",
        "ubi",
        "manufacturerData",
        "adapter",
        "AdapterPtr",
        "gattServices",
        "Phone",
        "Modem",
        "Computer",
        "Network",
        "Headset",
        "Headphones",
        "AudioVideo",
        "Keyboard",
        "Mouse",
        "Joypad",
        "Tablet",
        "Peripheral",
        "Camera",
        "Printer",
        "Imaging",
        "Wearable",
        "Toy",
        "Health",
        "Uncategorized"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(DevicePtr)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void(DevicePtr)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'gattServiceAdded'
        QtMocHelpers::SignalData<void(GattServiceRemotePtr)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'gattServicesChanged'
        QtMocHelpers::SignalData<void(QList<GattServiceRemotePtr>)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'gattServiceRemoved'
        QtMocHelpers::SignalData<void(GattServiceRemotePtr)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'gattServiceChanged'
        QtMocHelpers::SignalData<void(GattServiceRemotePtr)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'addressChanged'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'friendlyNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'remoteNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'deviceClassChanged'
        QtMocHelpers::SignalData<void(quint32)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 23 },
        }}),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(enum Type)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Signal 'appearanceChanged'
        QtMocHelpers::SignalData<void(quint16)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 28 },
        }}),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Signal 'pairedChanged'
        QtMocHelpers::SignalData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Signal 'trustedChanged'
        QtMocHelpers::SignalData<void(bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Signal 'blockedChanged'
        QtMocHelpers::SignalData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Signal 'legacyPairingChanged'
        QtMocHelpers::SignalData<void(bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Signal 'rssiChanged'
        QtMocHelpers::SignalData<void(qint16)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Short, 40 },
        }}),
        // Signal 'manufacturerDataChanged'
        QtMocHelpers::SignalData<void(ManData)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Signal 'servicesResolvedChanged'
        QtMocHelpers::SignalData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Signal 'connectedChanged'
        QtMocHelpers::SignalData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
        // Signal 'uuidsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 49 },
        }}),
        // Signal 'modaliasChanged'
        QtMocHelpers::SignalData<void(const QString &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 51 },
        }}),
        // Signal 'serviceDataChanged'
        QtMocHelpers::SignalData<void(const QHash<QString,QByteArray> &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Signal 'batteryChanged'
        QtMocHelpers::SignalData<void(BatteryPtr)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Signal 'inputChanged'
        QtMocHelpers::SignalData<void(InputPtr)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Signal 'mediaPlayerChanged'
        QtMocHelpers::SignalData<void(MediaPlayerPtr)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
        // Signal 'mediaTransportChanged'
        QtMocHelpers::SignalData<void(MediaTransportPtr)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 65, 66 },
        }}),
        // Slot 'connectToDevice'
        QtMocHelpers::SlotData<PendingCall *()>(67, 2, QMC::AccessPublic, 0x80000000 | 68),
        // Slot 'disconnectFromDevice'
        QtMocHelpers::SlotData<PendingCall *()>(69, 2, QMC::AccessPublic, 0x80000000 | 68),
        // Slot 'connectProfile'
        QtMocHelpers::SlotData<PendingCall *(const QString &)>(70, 2, QMC::AccessPublic, 0x80000000 | 68, {{
            { QMetaType::QString, 71 },
        }}),
        // Slot 'disconnectProfile'
        QtMocHelpers::SlotData<PendingCall *(const QString &)>(72, 2, QMC::AccessPublic, 0x80000000 | 68, {{
            { QMetaType::QString, 71 },
        }}),
        // Slot 'pair'
        QtMocHelpers::SlotData<PendingCall *()>(73, 2, QMC::AccessPublic, 0x80000000 | 68),
        // Slot 'cancelPairing'
        QtMocHelpers::SlotData<PendingCall *()>(74, 2, QMC::AccessPublic, 0x80000000 | 68),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ubi'
        QtMocHelpers::PropertyData<QString>(75, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'address'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'friendlyName'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'remoteName'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'deviceClass'
        QtMocHelpers::PropertyData<quint32>(23, QMetaType::UInt, QMC::DefaultPropertyFlags, 10),
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(26, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'appearance'
        QtMocHelpers::PropertyData<quint16>(28, QMetaType::UShort, QMC::DefaultPropertyFlags, 12),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'paired'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'trusted'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'blocked'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'legacyPairing'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags, 17),
        // property 'rssi'
        QtMocHelpers::PropertyData<qint16>(40, QMetaType::Short, QMC::DefaultPropertyFlags, 18),
        // property 'manufacturerData'
        QtMocHelpers::PropertyData<ManData>(76, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 19),
        // property 'servicesResolved'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags, 21),
        // property 'uuids'
        QtMocHelpers::PropertyData<QStringList>(49, QMetaType::QStringList, QMC::DefaultPropertyFlags, 22),
        // property 'modalias'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags, 23),
        // property 'battery'
        QtMocHelpers::PropertyData<BatteryPtr>(57, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 25),
        // property 'input'
        QtMocHelpers::PropertyData<InputPtr>(60, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 26),
        // property 'mediaPlayer'
        QtMocHelpers::PropertyData<MediaPlayerPtr>(63, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 27),
        // property 'mediaTransport'
        QtMocHelpers::PropertyData<MediaTransportPtr>(66, 0x80000000 | 65, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 28),
        // property 'adapter'
        QtMocHelpers::PropertyData<AdapterPtr>(77, 0x80000000 | 78, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'gattServices'
        QtMocHelpers::PropertyData<QList<GattServiceRemotePtr>>(79, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(25, 25, QMC::EnumFlags{}).add({
            {   80, Type::Phone },
            {   81, Type::Modem },
            {   82, Type::Computer },
            {   83, Type::Network },
            {   84, Type::Headset },
            {   85, Type::Headphones },
            {   86, Type::AudioVideo },
            {   87, Type::Keyboard },
            {   88, Type::Mouse },
            {   89, Type::Joypad },
            {   90, Type::Tablet },
            {   91, Type::Peripheral },
            {   92, Type::Camera },
            {   93, Type::Printer },
            {   94, Type::Imaging },
            {   95, Type::Wearable },
            {   96, Type::Toy },
            {   97, Type::Health },
            {   98, Type::Uncategorized },
        }),
    };
    return QtMocHelpers::metaObjectData<Device, qt_meta_tag_ZN7BluezQt6DeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::Device::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt6DeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt6DeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt6DeviceE_t>.metaTypes,
    nullptr
} };

void BluezQt::Device::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Device *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<DevicePtr>>(_a[1]))); break;
        case 1: _t->deviceChanged((*reinterpret_cast<std::add_pointer_t<DevicePtr>>(_a[1]))); break;
        case 2: _t->gattServiceAdded((*reinterpret_cast<std::add_pointer_t<GattServiceRemotePtr>>(_a[1]))); break;
        case 3: _t->gattServicesChanged((*reinterpret_cast<std::add_pointer_t<QList<GattServiceRemotePtr>>>(_a[1]))); break;
        case 4: _t->gattServiceRemoved((*reinterpret_cast<std::add_pointer_t<GattServiceRemotePtr>>(_a[1]))); break;
        case 5: _t->gattServiceChanged((*reinterpret_cast<std::add_pointer_t<GattServiceRemotePtr>>(_a[1]))); break;
        case 6: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->addressChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->friendlyNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->remoteNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->deviceClassChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 11: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<enum Type>>(_a[1]))); break;
        case 12: _t->appearanceChanged((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 13: _t->iconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->pairedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->trustedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->blockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->legacyPairingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->rssiChanged((*reinterpret_cast<std::add_pointer_t<qint16>>(_a[1]))); break;
        case 19: _t->manufacturerDataChanged((*reinterpret_cast<std::add_pointer_t<ManData>>(_a[1]))); break;
        case 20: _t->servicesResolvedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->connectedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->uuidsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 23: _t->modaliasChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->serviceDataChanged((*reinterpret_cast<std::add_pointer_t<QHash<QString,QByteArray>>>(_a[1]))); break;
        case 25: _t->batteryChanged((*reinterpret_cast<std::add_pointer_t<BatteryPtr>>(_a[1]))); break;
        case 26: _t->inputChanged((*reinterpret_cast<std::add_pointer_t<InputPtr>>(_a[1]))); break;
        case 27: _t->mediaPlayerChanged((*reinterpret_cast<std::add_pointer_t<MediaPlayerPtr>>(_a[1]))); break;
        case 28: _t->mediaTransportChanged((*reinterpret_cast<std::add_pointer_t<MediaTransportPtr>>(_a[1]))); break;
        case 29: { PendingCall* _r = _t->connectToDevice();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 30: { PendingCall* _r = _t->disconnectFromDevice();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 31: { PendingCall* _r = _t->connectProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 32: { PendingCall* _r = _t->disconnectProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 33: { PendingCall* _r = _t->pair();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 34: { PendingCall* _r = _t->cancelPairing();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Device::*)(DevicePtr )>(_a, &Device::deviceRemoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(DevicePtr )>(_a, &Device::deviceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(GattServiceRemotePtr )>(_a, &Device::gattServiceAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(QList<GattServiceRemotePtr> )>(_a, &Device::gattServicesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(GattServiceRemotePtr )>(_a, &Device::gattServiceRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(GattServiceRemotePtr )>(_a, &Device::gattServiceChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(const QString & )>(_a, &Device::nameChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(const QString & )>(_a, &Device::addressChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(const QString & )>(_a, &Device::friendlyNameChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(const QString & )>(_a, &Device::remoteNameChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(quint32 )>(_a, &Device::deviceClassChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(Type )>(_a, &Device::typeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(quint16 )>(_a, &Device::appearanceChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(const QString & )>(_a, &Device::iconChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(bool )>(_a, &Device::pairedChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(bool )>(_a, &Device::trustedChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(bool )>(_a, &Device::blockedChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(bool )>(_a, &Device::legacyPairingChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(qint16 )>(_a, &Device::rssiChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(ManData )>(_a, &Device::manufacturerDataChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(bool )>(_a, &Device::servicesResolvedChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(bool )>(_a, &Device::connectedChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(const QStringList & )>(_a, &Device::uuidsChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(const QString & )>(_a, &Device::modaliasChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(const QHash<QString,QByteArray> & )>(_a, &Device::serviceDataChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(BatteryPtr )>(_a, &Device::batteryChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(InputPtr )>(_a, &Device::inputChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(MediaPlayerPtr )>(_a, &Device::mediaPlayerChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(MediaTransportPtr )>(_a, &Device::mediaTransportChanged, 28))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->ubi(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->address(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->friendlyName(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->remoteName(); break;
        case 5: *reinterpret_cast<quint32*>(_v) = _t->deviceClass(); break;
        case 6: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        case 7: *reinterpret_cast<quint16*>(_v) = _t->appearance(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->icon(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isPaired(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isTrusted(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isBlocked(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->hasLegacyPairing(); break;
        case 13: *reinterpret_cast<qint16*>(_v) = _t->rssi(); break;
        case 14: *reinterpret_cast<ManData*>(_v) = _t->manufacturerData(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isServicesResolved(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isConnected(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->uuids(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->modalias(); break;
        case 19: *reinterpret_cast<BatteryPtr*>(_v) = _t->battery(); break;
        case 20: *reinterpret_cast<InputPtr*>(_v) = _t->input(); break;
        case 21: *reinterpret_cast<MediaPlayerPtr*>(_v) = _t->mediaPlayer(); break;
        case 22: *reinterpret_cast<MediaTransportPtr*>(_v) = _t->mediaTransport(); break;
        case 23: *reinterpret_cast<AdapterPtr*>(_v) = _t->adapter(); break;
        case 24: *reinterpret_cast<QList<GattServiceRemotePtr>*>(_v) = _t->gattServices(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setTrusted(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setBlocked(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::Device::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::Device::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt6DeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::Device::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 35;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::Device::deviceRemoved(DevicePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::Device::deviceChanged(DevicePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluezQt::Device::gattServiceAdded(GattServiceRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluezQt::Device::gattServicesChanged(QList<GattServiceRemotePtr> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BluezQt::Device::gattServiceRemoved(GattServiceRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BluezQt::Device::gattServiceChanged(GattServiceRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluezQt::Device::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BluezQt::Device::addressChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BluezQt::Device::friendlyNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void BluezQt::Device::remoteNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void BluezQt::Device::deviceClassChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void BluezQt::Device::typeChanged(Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void BluezQt::Device::appearanceChanged(quint16 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void BluezQt::Device::iconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void BluezQt::Device::pairedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void BluezQt::Device::trustedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void BluezQt::Device::blockedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void BluezQt::Device::legacyPairingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void BluezQt::Device::rssiChanged(qint16 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void BluezQt::Device::manufacturerDataChanged(ManData _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void BluezQt::Device::servicesResolvedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void BluezQt::Device::connectedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void BluezQt::Device::uuidsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void BluezQt::Device::modaliasChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void BluezQt::Device::serviceDataChanged(const QHash<QString,QByteArray> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void BluezQt::Device::batteryChanged(BatteryPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void BluezQt::Device::inputChanged(InputPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void BluezQt::Device::mediaPlayerChanged(MediaPlayerPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void BluezQt::Device::mediaTransportChanged(MediaTransportPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}
QT_WARNING_POP
