/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.bluez.obex.FileTransfer1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef OBEXFILETRANSFER1_H
#define OBEXFILETRANSFER1_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "bluezqt_dbustypes.h"

/*
 * Proxy class for interface org.bluez.obex.FileTransfer1
 */
class OrgBluezObexFileTransfer1Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.bluez.obex.FileTransfer1"; }

public:
    OrgBluezObexFileTransfer1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgBluezObexFileTransfer1Interface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> ChangeFolder(const QString &folder)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(folder);
        return asyncCallWithArgumentList(QStringLiteral("ChangeFolder"), argumentList);
    }

    inline QDBusPendingReply<> CopyFile(const QString &sourcefile, const QString &targetfile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(sourcefile) << QVariant::fromValue(targetfile);
        return asyncCallWithArgumentList(QStringLiteral("CopyFile"), argumentList);
    }

    inline QDBusPendingReply<> CreateFolder(const QString &folder)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(folder);
        return asyncCallWithArgumentList(QStringLiteral("CreateFolder"), argumentList);
    }

    inline QDBusPendingReply<> Delete(const QString &file)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(file);
        return asyncCallWithArgumentList(QStringLiteral("Delete"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath, QVariantMap> GetFile(const QString &targetfile, const QString &sourcefile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(targetfile) << QVariant::fromValue(sourcefile);
        return asyncCallWithArgumentList(QStringLiteral("GetFile"), argumentList);
    }
    inline QDBusReply<QDBusObjectPath> GetFile(const QString &targetfile, const QString &sourcefile, QVariantMap &properties)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(targetfile) << QVariant::fromValue(sourcefile);
        QDBusMessage reply = callWithArgumentList(QDBus::Block, QStringLiteral("GetFile"), argumentList);
        if (reply.type() == QDBusMessage::ReplyMessage && reply.arguments().size() == 2) {
            properties = qdbus_cast<QVariantMap>(reply.arguments().at(1));
        }
        return reply;
    }

    inline QDBusPendingReply<QVariantMapList> ListFolder()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ListFolder"), argumentList);
    }

    inline QDBusPendingReply<> MoveFile(const QString &sourcefile, const QString &targetfile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(sourcefile) << QVariant::fromValue(targetfile);
        return asyncCallWithArgumentList(QStringLiteral("MoveFile"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath, QVariantMap> PutFile(const QString &sourcefile, const QString &targetfile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(sourcefile) << QVariant::fromValue(targetfile);
        return asyncCallWithArgumentList(QStringLiteral("PutFile"), argumentList);
    }
    inline QDBusReply<QDBusObjectPath> PutFile(const QString &sourcefile, const QString &targetfile, QVariantMap &properties)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(sourcefile) << QVariant::fromValue(targetfile);
        QDBusMessage reply = callWithArgumentList(QDBus::Block, QStringLiteral("PutFile"), argumentList);
        if (reply.type() == QDBusMessage::ReplyMessage && reply.arguments().size() == 2) {
            properties = qdbus_cast<QVariantMap>(reply.arguments().at(1));
        }
        return reply;
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace bluez {
    namespace obex {
      using FileTransfer1 = ::OrgBluezObexFileTransfer1Interface;
    }
  }
}

#endif
