/****************************************************************************
** Meta object code from reading C++ file 'declarativemediaplayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../bluez-qt-6.25.0/src/imports/declarativemediaplayer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativemediaplayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22DeclarativeMediaPlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeMediaPlayer::qt_create_metaobjectdata<qt_meta_tag_ZN22DeclarativeMediaPlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeMediaPlayer",
        "QML.Element",
        "MediaPlayer",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "MediaPlayer cannot be created",
        "nameChanged",
        "",
        "name",
        "equalizerChanged",
        "BluezQt::MediaPlayer::Equalizer",
        "equalizer",
        "repeatChanged",
        "BluezQt::MediaPlayer::Repeat",
        "repeat",
        "shuffleChanged",
        "BluezQt::MediaPlayer::Shuffle",
        "shuffle",
        "statusChanged",
        "BluezQt::MediaPlayer::Status",
        "status",
        "trackChanged",
        "QJsonObject",
        "track",
        "positionChanged",
        "position",
        "play",
        "BluezQt::PendingCall*",
        "pause",
        "stop",
        "next",
        "previous",
        "fastForward",
        "rewind"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'equalizerChanged'
        QtMocHelpers::SignalData<void(BluezQt::MediaPlayer::Equalizer)>(10, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'repeatChanged'
        QtMocHelpers::SignalData<void(BluezQt::MediaPlayer::Repeat)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'shuffleChanged'
        QtMocHelpers::SignalData<void(BluezQt::MediaPlayer::Shuffle)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(BluezQt::MediaPlayer::Status)>(19, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'trackChanged'
        QtMocHelpers::SignalData<void(const QJsonObject &)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(quint32)>(25, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 26 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(27, 8, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'pause'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(29, 8, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'stop'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(30, 8, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'next'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(31, 8, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'previous'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(32, 8, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'fastForward'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(33, 8, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'rewind'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(34, 8, QMC::AccessPublic, 0x80000000 | 28),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'equalizer'
        QtMocHelpers::PropertyData<BluezQt::MediaPlayer::Equalizer>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'repeat'
        QtMocHelpers::PropertyData<BluezQt::MediaPlayer::Repeat>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'shuffle'
        QtMocHelpers::PropertyData<BluezQt::MediaPlayer::Shuffle>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'status'
        QtMocHelpers::PropertyData<BluezQt::MediaPlayer::Status>(21, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'track'
        QtMocHelpers::PropertyData<QJsonObject>(24, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'position'
        QtMocHelpers::PropertyData<quint32>(26, QMetaType::UInt, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeMediaPlayer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN22DeclarativeMediaPlayerE[] = {
    QMetaObject::SuperData::link<BluezQt::MediaPlayer::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject DeclarativeMediaPlayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DeclarativeMediaPlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DeclarativeMediaPlayerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN22DeclarativeMediaPlayerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22DeclarativeMediaPlayerE_t>.metaTypes,
    nullptr
} };

void DeclarativeMediaPlayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeMediaPlayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->equalizerChanged((*reinterpret_cast<std::add_pointer_t<BluezQt::MediaPlayer::Equalizer>>(_a[1]))); break;
        case 2: _t->repeatChanged((*reinterpret_cast<std::add_pointer_t<BluezQt::MediaPlayer::Repeat>>(_a[1]))); break;
        case 3: _t->shuffleChanged((*reinterpret_cast<std::add_pointer_t<BluezQt::MediaPlayer::Shuffle>>(_a[1]))); break;
        case 4: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<BluezQt::MediaPlayer::Status>>(_a[1]))); break;
        case 5: _t->trackChanged((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1]))); break;
        case 6: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 7: { BluezQt::PendingCall* _r = _t->play();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 8: { BluezQt::PendingCall* _r = _t->pause();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 9: { BluezQt::PendingCall* _r = _t->stop();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 10: { BluezQt::PendingCall* _r = _t->next();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 11: { BluezQt::PendingCall* _r = _t->previous();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 12: { BluezQt::PendingCall* _r = _t->fastForward();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 13: { BluezQt::PendingCall* _r = _t->rewind();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMediaPlayer::*)(const QString & )>(_a, &DeclarativeMediaPlayer::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMediaPlayer::*)(BluezQt::MediaPlayer::Equalizer )>(_a, &DeclarativeMediaPlayer::equalizerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMediaPlayer::*)(BluezQt::MediaPlayer::Repeat )>(_a, &DeclarativeMediaPlayer::repeatChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMediaPlayer::*)(BluezQt::MediaPlayer::Shuffle )>(_a, &DeclarativeMediaPlayer::shuffleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMediaPlayer::*)(BluezQt::MediaPlayer::Status )>(_a, &DeclarativeMediaPlayer::statusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMediaPlayer::*)(const QJsonObject & )>(_a, &DeclarativeMediaPlayer::trackChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeMediaPlayer::*)(quint32 )>(_a, &DeclarativeMediaPlayer::positionChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<BluezQt::MediaPlayer::Equalizer*>(_v) = _t->equalizer(); break;
        case 2: *reinterpret_cast<BluezQt::MediaPlayer::Repeat*>(_v) = _t->repeat(); break;
        case 3: *reinterpret_cast<BluezQt::MediaPlayer::Shuffle*>(_v) = _t->shuffle(); break;
        case 4: *reinterpret_cast<BluezQt::MediaPlayer::Status*>(_v) = _t->status(); break;
        case 5: *reinterpret_cast<QJsonObject*>(_v) = _t->track(); break;
        case 6: *reinterpret_cast<quint32*>(_v) = _t->position(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setEqualizer(*reinterpret_cast<BluezQt::MediaPlayer::Equalizer*>(_v)); break;
        case 2: _t->setRepeat(*reinterpret_cast<BluezQt::MediaPlayer::Repeat*>(_v)); break;
        case 3: _t->setShuffle(*reinterpret_cast<BluezQt::MediaPlayer::Shuffle*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeMediaPlayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeMediaPlayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DeclarativeMediaPlayerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeclarativeMediaPlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeMediaPlayer::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeMediaPlayer::equalizerChanged(BluezQt::MediaPlayer::Equalizer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeMediaPlayer::repeatChanged(BluezQt::MediaPlayer::Repeat _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeMediaPlayer::shuffleChanged(BluezQt::MediaPlayer::Shuffle _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeclarativeMediaPlayer::statusChanged(BluezQt::MediaPlayer::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DeclarativeMediaPlayer::trackChanged(const QJsonObject & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DeclarativeMediaPlayer::positionChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
