/****************************************************************************
** Meta object code from reading C++ file 'bluezmediatransport1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "bluezmediatransport1.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluezmediatransport1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32OrgBluezMediaTransport1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgBluezMediaTransport1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN32OrgBluezMediaTransport1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgBluezMediaTransport1Interface",
        "Acquire",
        "QDBusPendingReply<QDBusUnixFileDescriptor,ushort,ushort>",
        "",
        "QDBusReply<QDBusUnixFileDescriptor>",
        "ushort&",
        "mtu_r",
        "mtu_w",
        "Release",
        "QDBusPendingReply<>",
        "TryAcquire",
        "Codec",
        "Configuration",
        "Delay",
        "Device",
        "QDBusObjectPath",
        "State",
        "UUID",
        "Volume"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Acquire'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusUnixFileDescriptor,ushort,ushort>()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'Acquire'
        QtMocHelpers::SlotData<QDBusReply<QDBusUnixFileDescriptor>(ushort &, ushort &)>(1, 3, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Slot 'Release'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(8, 3, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'TryAcquire'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusUnixFileDescriptor,ushort,ushort>()>(10, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'TryAcquire'
        QtMocHelpers::SlotData<QDBusReply<QDBusUnixFileDescriptor>(ushort &, ushort &)>(10, 3, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Codec'
        QtMocHelpers::PropertyData<uchar>(11, QMetaType::UChar, QMC::DefaultPropertyFlags),
        // property 'Configuration'
        QtMocHelpers::PropertyData<QByteArray>(12, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
        // property 'Delay'
        QtMocHelpers::PropertyData<ushort>(13, QMetaType::UShort, QMC::DefaultPropertyFlags),
        // property 'Device'
        QtMocHelpers::PropertyData<QDBusObjectPath>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'State'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'UUID'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Volume'
        QtMocHelpers::PropertyData<ushort>(18, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgBluezMediaTransport1Interface, qt_meta_tag_ZN32OrgBluezMediaTransport1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgBluezMediaTransport1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgBluezMediaTransport1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgBluezMediaTransport1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32OrgBluezMediaTransport1InterfaceE_t>.metaTypes,
    nullptr
} };

void OrgBluezMediaTransport1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgBluezMediaTransport1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<QDBusUnixFileDescriptor,ushort,ushort> _r = _t->Acquire();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusUnixFileDescriptor,ushort,ushort>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusReply<QDBusUnixFileDescriptor> _r = _t->Acquire((*reinterpret_cast<std::add_pointer_t<ushort&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ushort&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QDBusUnixFileDescriptor>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->Release();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QDBusUnixFileDescriptor,ushort,ushort> _r = _t->TryAcquire();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusUnixFileDescriptor,ushort,ushort>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusReply<QDBusUnixFileDescriptor> _r = _t->TryAcquire((*reinterpret_cast<std::add_pointer_t<ushort&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ushort&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QDBusUnixFileDescriptor>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uchar*>(_v) = _t->codec(); break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->configuration(); break;
        case 2: *reinterpret_cast<ushort*>(_v) = _t->delay(); break;
        case 3: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->device(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->state(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->uUID(); break;
        case 6: *reinterpret_cast<ushort*>(_v) = _t->volume(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setVolume(*reinterpret_cast<ushort*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OrgBluezMediaTransport1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgBluezMediaTransport1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgBluezMediaTransport1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgBluezMediaTransport1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
