/****************************************************************************
** Meta object code from reading C++ file 'pendingcall.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/pendingcall.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pendingcall.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt11PendingCallE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::PendingCall::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt11PendingCallE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::PendingCall",
        "finished",
        "",
        "PendingCall*",
        "call",
        "value",
        "QVariant",
        "values",
        "QVariantList",
        "error",
        "errorText",
        "isFinished",
        "userData",
        "Error",
        "NoError",
        "NotReady",
        "Failed",
        "Rejected",
        "Canceled",
        "InvalidArguments",
        "AlreadyExists",
        "DoesNotExist",
        "InProgress",
        "NotInProgress",
        "AlreadyConnected",
        "ConnectFailed",
        "NotConnected",
        "NotSupported",
        "NotAuthorized",
        "AuthenticationCanceled",
        "AuthenticationFailed",
        "AuthenticationRejected",
        "AuthenticationTimeout",
        "ConnectionAttemptFailed",
        "InvalidLength",
        "NotPermitted",
        "DBusError",
        "InternalError",
        "UnknownError"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(PendingCall *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<QVariant>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'values'
        QtMocHelpers::PropertyData<QVariantList>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'error'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'errorText'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'isFinished'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'userData'
        QtMocHelpers::PropertyData<QVariant>(12, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Error'
        QtMocHelpers::EnumData<enum Error>(13, 13, QMC::EnumFlags{}).add({
            {   14, Error::NoError },
            {   15, Error::NotReady },
            {   16, Error::Failed },
            {   17, Error::Rejected },
            {   18, Error::Canceled },
            {   19, Error::InvalidArguments },
            {   20, Error::AlreadyExists },
            {   21, Error::DoesNotExist },
            {   22, Error::InProgress },
            {   23, Error::NotInProgress },
            {   24, Error::AlreadyConnected },
            {   25, Error::ConnectFailed },
            {   26, Error::NotConnected },
            {   27, Error::NotSupported },
            {   28, Error::NotAuthorized },
            {   29, Error::AuthenticationCanceled },
            {   30, Error::AuthenticationFailed },
            {   31, Error::AuthenticationRejected },
            {   32, Error::AuthenticationTimeout },
            {   33, Error::ConnectionAttemptFailed },
            {   34, Error::InvalidLength },
            {   35, Error::NotPermitted },
            {   36, Error::DBusError },
            {   37, Error::InternalError },
            {   38, Error::UnknownError },
        }),
    };
    return QtMocHelpers::metaObjectData<PendingCall, qt_meta_tag_ZN7BluezQt11PendingCallE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::PendingCall::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt11PendingCallE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt11PendingCallE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt11PendingCallE_t>.metaTypes,
    nullptr
} };

void BluezQt::PendingCall::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PendingCall *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<PendingCall*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PendingCall* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PendingCall::*)(PendingCall * )>(_a, &PendingCall::finished, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->value(); break;
        case 1: *reinterpret_cast<QVariantList*>(_v) = _t->values(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->error(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->errorText(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isFinished(); break;
        case 5: *reinterpret_cast<QVariant*>(_v) = _t->userData(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setUserData(*reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::PendingCall::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::PendingCall::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt11PendingCallE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::PendingCall::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::PendingCall::finished(PendingCall * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
