/****************************************************************************
** Meta object code from reading C++ file 'agentadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/agentadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt12AgentAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::AgentAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt12AgentAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::AgentAdaptor",
        "D-Bus Interface",
        "org.bluez.Agent1",
        "RequestPinCode",
        "",
        "QDBusObjectPath",
        "device",
        "QDBusMessage",
        "msg",
        "DisplayPinCode",
        "Q_NOREPLY",
        "pincode",
        "RequestPasskey",
        "DisplayPasskey",
        "passkey",
        "entered",
        "RequestConfirmation",
        "RequestAuthorization",
        "AuthorizeService",
        "uuid",
        "Cancel",
        "Release"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'RequestPinCode'
        QtMocHelpers::SlotData<QString(const QDBusObjectPath &, const QDBusMessage &)>(3, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'DisplayPinCode'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &)>(9, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'RequestPasskey'
        QtMocHelpers::SlotData<quint32(const QDBusObjectPath &, const QDBusMessage &)>(12, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'DisplayPasskey'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, quint32, quint16)>(13, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::UInt, 14 }, { QMetaType::UShort, 15 },
        }}),
        // Slot 'RequestConfirmation'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, quint32, const QDBusMessage &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::UInt, 14 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'RequestAuthorization'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusMessage &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'AuthorizeService'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &, const QDBusMessage &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 19 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'Cancel'
        QtMocHelpers::SlotData<void()>(20, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Release'
        QtMocHelpers::SlotData<void()>(21, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AgentAdaptor, qt_meta_tag_ZN7BluezQt12AgentAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BluezQt::AgentAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt12AgentAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt12AgentAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt12AgentAdaptorE_t>.metaTypes,
    nullptr
} };

void BluezQt::AgentAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgentAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->RequestPinCode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->DisplayPinCode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: { quint32 _r = _t->RequestPasskey((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2])));
            if (_a[0]) *reinterpret_cast<quint32*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->DisplayPasskey((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint16>>(_a[3]))); break;
        case 4: _t->RequestConfirmation((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3]))); break;
        case 5: _t->RequestAuthorization((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[2]))); break;
        case 6: _t->AuthorizeService((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[3]))); break;
        case 7: _t->Cancel(); break;
        case 8: _t->Release(); break;
        default: ;
        }
    }
}

const QMetaObject *BluezQt::AgentAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::AgentAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt12AgentAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int BluezQt::AgentAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
