/****************************************************************************
** Meta object code from reading C++ file 'obextransfer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/obextransfer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'obextransfer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt12ObexTransferE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::ObexTransfer::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt12ObexTransferE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::ObexTransfer",
        "statusChanged",
        "",
        "Status",
        "status",
        "transferredChanged",
        "transferred",
        "fileNameChanged",
        "fileName",
        "name",
        "type",
        "time",
        "size",
        "suspendable",
        "Queued",
        "Active",
        "Suspended",
        "Complete",
        "Error",
        "Unknown"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(enum Status)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'transferredChanged'
        QtMocHelpers::SignalData<void(quint64)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 6 },
        }}),
        // Signal 'fileNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'time'
        QtMocHelpers::PropertyData<quint64>(11, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'size'
        QtMocHelpers::PropertyData<quint64>(12, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'transferred'
        QtMocHelpers::PropertyData<quint64>(6, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 1),
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'suspendable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(3, 3, QMC::EnumFlags{}).add({
            {   14, Status::Queued },
            {   15, Status::Active },
            {   16, Status::Suspended },
            {   17, Status::Complete },
            {   18, Status::Error },
            {   19, Status::Unknown },
        }),
    };
    return QtMocHelpers::metaObjectData<ObexTransfer, qt_meta_tag_ZN7BluezQt12ObexTransferE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::ObexTransfer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt12ObexTransferE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt12ObexTransferE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt12ObexTransferE_t>.metaTypes,
    nullptr
} };

void BluezQt::ObexTransfer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ObexTransfer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<enum Status>>(_a[1]))); break;
        case 1: _t->transferredChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 2: _t->fileNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ObexTransfer::*)(Status )>(_a, &ObexTransfer::statusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ObexTransfer::*)(quint64 )>(_a, &ObexTransfer::transferredChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ObexTransfer::*)(const QString & )>(_a, &ObexTransfer::fileNameChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 3: *reinterpret_cast<quint64*>(_v) = _t->time(); break;
        case 4: *reinterpret_cast<quint64*>(_v) = _t->size(); break;
        case 5: *reinterpret_cast<quint64*>(_v) = _t->transferred(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isSuspendable(); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::ObexTransfer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::ObexTransfer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt12ObexTransferE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::ObexTransfer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::ObexTransfer::statusChanged(Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::ObexTransfer::transferredChanged(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluezQt::ObexTransfer::fileNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
