/****************************************************************************
** Meta object code from reading C++ file 'obexmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/obexmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'obexmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt11ObexManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::ObexManager::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt11ObexManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::ObexManager",
        "operationalChanged",
        "",
        "operational",
        "sessionAdded",
        "ObexSessionPtr",
        "session",
        "sessionRemoved",
        "registerAgent",
        "PendingCall*",
        "ObexAgent*",
        "agent",
        "unregisterAgent",
        "createSession",
        "destination",
        "QVariantMap",
        "args",
        "removeSession",
        "QDBusObjectPath",
        "initialized",
        "sessions",
        "QList<ObexSessionPtr>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'operationalChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'sessionAdded'
        QtMocHelpers::SignalData<void(ObexSessionPtr)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'sessionRemoved'
        QtMocHelpers::SignalData<void(ObexSessionPtr)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'registerAgent'
        QtMocHelpers::SlotData<PendingCall *(ObexAgent *)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'unregisterAgent'
        QtMocHelpers::SlotData<PendingCall *(ObexAgent *)>(12, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'createSession'
        QtMocHelpers::SlotData<PendingCall *(const QString &, const QVariantMap &)>(13, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'removeSession'
        QtMocHelpers::SlotData<PendingCall *(const QDBusObjectPath &)>(17, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 18, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'initialized'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'operational'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'sessions'
        QtMocHelpers::PropertyData<QList<ObexSessionPtr>>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ObexManager, qt_meta_tag_ZN7BluezQt11ObexManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::ObexManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt11ObexManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt11ObexManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt11ObexManagerE_t>.metaTypes,
    nullptr
} };

void BluezQt::ObexManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ObexManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->operationalChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->sessionAdded((*reinterpret_cast<std::add_pointer_t<ObexSessionPtr>>(_a[1]))); break;
        case 2: _t->sessionRemoved((*reinterpret_cast<std::add_pointer_t<ObexSessionPtr>>(_a[1]))); break;
        case 3: { PendingCall* _r = _t->registerAgent((*reinterpret_cast<std::add_pointer_t<ObexAgent*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 4: { PendingCall* _r = _t->unregisterAgent((*reinterpret_cast<std::add_pointer_t<ObexAgent*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 5: { PendingCall* _r = _t->createSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 6: { PendingCall* _r = _t->removeSession((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ObexManager::*)(bool )>(_a, &ObexManager::operationalChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ObexManager::*)(ObexSessionPtr )>(_a, &ObexManager::sessionAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ObexManager::*)(ObexSessionPtr )>(_a, &ObexManager::sessionRemoved, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isInitialized(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isOperational(); break;
        case 2: *reinterpret_cast<QList<ObexSessionPtr>*>(_v) = _t->sessions(); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::ObexManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::ObexManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt11ObexManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::ObexManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::ObexManager::operationalChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::ObexManager::sessionAdded(ObexSessionPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluezQt::ObexManager::sessionRemoved(ObexSessionPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
