/****************************************************************************
** Meta object code from reading C++ file 'declarativeadapter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../bluez-qt-6.25.0/src/imports/declarativeadapter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativeadapter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18DeclarativeAdapterE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeAdapter::qt_create_metaobjectdata<qt_meta_tag_ZN18DeclarativeAdapterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeAdapter",
        "QML.Element",
        "Adapter",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Adapter cannot be created",
        "adapterRemoved",
        "",
        "DeclarativeAdapter*",
        "adapter",
        "adapterChanged",
        "nameChanged",
        "name",
        "systemNameChanged",
        "adapterClassChanged",
        "adapterClass",
        "poweredChanged",
        "powered",
        "discoverableChanged",
        "discoverable",
        "discoverableTimeoutChanged",
        "timeout",
        "pairableChanged",
        "pairable",
        "pairableTimeoutChanged",
        "discoveringChanged",
        "discovering",
        "uuidsChanged",
        "uuids",
        "modaliasChanged",
        "modalias",
        "deviceFound",
        "DeclarativeDevice*",
        "device",
        "deviceRemoved",
        "deviceChanged",
        "devicesChanged",
        "QQmlListProperty<DeclarativeDevice>",
        "devices",
        "deviceForAddress",
        "address",
        "startDiscovery",
        "BluezQt::PendingCall*",
        "stopDiscovery",
        "removeDevice",
        "slotDeviceAdded",
        "BluezQt::DevicePtr",
        "slotDeviceRemoved",
        "ubi",
        "systemName",
        "discoverableTimeout",
        "pairableTimeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'adapterRemoved'
        QtMocHelpers::SignalData<void(DeclarativeAdapter *)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'adapterChanged'
        QtMocHelpers::SignalData<void(DeclarativeAdapter *)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'systemNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'adapterClassChanged'
        QtMocHelpers::SignalData<void(quint32)>(15, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 16 },
        }}),
        // Signal 'poweredChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'discoverableChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Signal 'discoverableTimeoutChanged'
        QtMocHelpers::SignalData<void(quint32)>(21, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 22 },
        }}),
        // Signal 'pairableChanged'
        QtMocHelpers::SignalData<void(bool)>(23, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'pairableTimeoutChanged'
        QtMocHelpers::SignalData<void(quint32)>(25, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 22 },
        }}),
        // Signal 'discoveringChanged'
        QtMocHelpers::SignalData<void(bool)>(26, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Signal 'uuidsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(28, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 29 },
        }}),
        // Signal 'modaliasChanged'
        QtMocHelpers::SignalData<void(const QString &)>(30, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Signal 'deviceFound'
        QtMocHelpers::SignalData<void(DeclarativeDevice *)>(32, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(DeclarativeDevice *)>(35, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void(DeclarativeDevice *)>(36, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Signal 'devicesChanged'
        QtMocHelpers::SignalData<void(QQmlListProperty<DeclarativeDevice>)>(37, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'deviceForAddress'
        QtMocHelpers::SlotData<DeclarativeDevice *(const QString &) const>(40, 8, QMC::AccessPublic, 0x80000000 | 33, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'startDiscovery'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(42, 8, QMC::AccessPublic, 0x80000000 | 43),
        // Slot 'stopDiscovery'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(44, 8, QMC::AccessPublic, 0x80000000 | 43),
        // Slot 'removeDevice'
        QtMocHelpers::SlotData<BluezQt::PendingCall *(DeclarativeDevice *)>(45, 8, QMC::AccessPublic, 0x80000000 | 43, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'slotDeviceAdded'
        QtMocHelpers::SlotData<void(BluezQt::DevicePtr)>(46, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 34 },
        }}),
        // Slot 'slotDeviceRemoved'
        QtMocHelpers::SlotData<void(BluezQt::DevicePtr)>(48, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ubi'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'address'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'systemName'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'adapterClass'
        QtMocHelpers::PropertyData<quint32>(16, QMetaType::UInt, QMC::DefaultPropertyFlags, 4),
        // property 'powered'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'discoverable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'discoverableTimeout'
        QtMocHelpers::PropertyData<quint32>(51, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'pairable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'pairableTimeout'
        QtMocHelpers::PropertyData<quint32>(52, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'discovering'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'uuids'
        QtMocHelpers::PropertyData<QStringList>(29, QMetaType::QStringList, QMC::DefaultPropertyFlags, 11),
        // property 'modalias'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'devices'
        QtMocHelpers::PropertyData<QQmlListProperty<DeclarativeDevice>>(39, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 16),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeAdapter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeAdapter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DeclarativeAdapterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DeclarativeAdapterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18DeclarativeAdapterE_t>.metaTypes,
    nullptr
} };

void DeclarativeAdapter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeAdapter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->adapterRemoved((*reinterpret_cast<std::add_pointer_t<DeclarativeAdapter*>>(_a[1]))); break;
        case 1: _t->adapterChanged((*reinterpret_cast<std::add_pointer_t<DeclarativeAdapter*>>(_a[1]))); break;
        case 2: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->systemNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->adapterClassChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 5: _t->poweredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->discoverableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->discoverableTimeoutChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 8: _t->pairableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->pairableTimeoutChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 10: _t->discoveringChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->uuidsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 12: _t->modaliasChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->deviceFound((*reinterpret_cast<std::add_pointer_t<DeclarativeDevice*>>(_a[1]))); break;
        case 14: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<DeclarativeDevice*>>(_a[1]))); break;
        case 15: _t->deviceChanged((*reinterpret_cast<std::add_pointer_t<DeclarativeDevice*>>(_a[1]))); break;
        case 16: _t->devicesChanged((*reinterpret_cast<std::add_pointer_t<QQmlListProperty<DeclarativeDevice>>>(_a[1]))); break;
        case 17: { DeclarativeDevice* _r = _t->deviceForAddress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeDevice**>(_a[0]) = std::move(_r); }  break;
        case 18: { BluezQt::PendingCall* _r = _t->startDiscovery();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 19: { BluezQt::PendingCall* _r = _t->stopDiscovery();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 20: { BluezQt::PendingCall* _r = _t->removeDevice((*reinterpret_cast<std::add_pointer_t<DeclarativeDevice*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 21: _t->slotDeviceAdded((*reinterpret_cast<std::add_pointer_t<BluezQt::DevicePtr>>(_a[1]))); break;
        case 22: _t->slotDeviceRemoved((*reinterpret_cast<std::add_pointer_t<BluezQt::DevicePtr>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DeclarativeAdapter* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DeclarativeAdapter* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DeclarativeDevice* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DeclarativeDevice* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DeclarativeDevice* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DeclarativeDevice* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(DeclarativeAdapter * )>(_a, &DeclarativeAdapter::adapterRemoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(DeclarativeAdapter * )>(_a, &DeclarativeAdapter::adapterChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(const QString & )>(_a, &DeclarativeAdapter::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(const QString & )>(_a, &DeclarativeAdapter::systemNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(quint32 )>(_a, &DeclarativeAdapter::adapterClassChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(bool )>(_a, &DeclarativeAdapter::poweredChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(bool )>(_a, &DeclarativeAdapter::discoverableChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(quint32 )>(_a, &DeclarativeAdapter::discoverableTimeoutChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(bool )>(_a, &DeclarativeAdapter::pairableChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(quint32 )>(_a, &DeclarativeAdapter::pairableTimeoutChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(bool )>(_a, &DeclarativeAdapter::discoveringChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(const QStringList & )>(_a, &DeclarativeAdapter::uuidsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(const QString & )>(_a, &DeclarativeAdapter::modaliasChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(DeclarativeDevice * )>(_a, &DeclarativeAdapter::deviceFound, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(DeclarativeDevice * )>(_a, &DeclarativeAdapter::deviceRemoved, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(DeclarativeDevice * )>(_a, &DeclarativeAdapter::deviceChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAdapter::*)(QQmlListProperty<DeclarativeDevice> )>(_a, &DeclarativeAdapter::devicesChanged, 16))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->ubi(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->address(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->systemName(); break;
        case 4: *reinterpret_cast<quint32*>(_v) = _t->adapterClass(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isPowered(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isDiscoverable(); break;
        case 7: *reinterpret_cast<quint32*>(_v) = _t->discoverableTimeout(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isPairable(); break;
        case 9: *reinterpret_cast<quint32*>(_v) = _t->pairableTimeout(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isDiscovering(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->uuids(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->modalias(); break;
        case 13: *reinterpret_cast<QQmlListProperty<DeclarativeDevice>*>(_v) = _t->devices(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setPowered(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setDiscoverable(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setDiscoverableTimeout(*reinterpret_cast<quint32*>(_v)); break;
        case 8: _t->setPairable(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setPairableTimeout(*reinterpret_cast<quint32*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeAdapter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeAdapter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DeclarativeAdapterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeclarativeAdapter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeAdapter::adapterRemoved(DeclarativeAdapter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeAdapter::adapterChanged(DeclarativeAdapter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeAdapter::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeAdapter::systemNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeclarativeAdapter::adapterClassChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DeclarativeAdapter::poweredChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DeclarativeAdapter::discoverableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DeclarativeAdapter::discoverableTimeoutChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DeclarativeAdapter::pairableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DeclarativeAdapter::pairableTimeoutChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DeclarativeAdapter::discoveringChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DeclarativeAdapter::uuidsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DeclarativeAdapter::modaliasChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DeclarativeAdapter::deviceFound(DeclarativeDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DeclarativeAdapter::deviceRemoved(DeclarativeDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DeclarativeAdapter::deviceChanged(DeclarativeDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DeclarativeAdapter::devicesChanged(QQmlListProperty<DeclarativeDevice> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}
QT_WARNING_POP
