/****************************************************************************
** Meta object code from reading C++ file 'gattserviceremote.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/gattserviceremote.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gattserviceremote.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt17GattServiceRemoteE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::GattServiceRemote::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt17GattServiceRemoteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::GattServiceRemote",
        "serviceChanged",
        "",
        "GattServiceRemotePtr",
        "service",
        "gattCharacteristicAdded",
        "GattCharacteristicRemotePtr",
        "characteristic",
        "characteristicsChanged",
        "QList<GattCharacteristicRemotePtr>",
        "characteristics",
        "gattCharacteristicRemoved",
        "gattCharacteristicChanged",
        "uuidChanged",
        "uuid",
        "primaryChanged",
        "primary",
        "handleChanged",
        "handle",
        "includesChanged",
        "QList<QDBusObjectPath>",
        "includes",
        "device",
        "DevicePtr"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'serviceChanged'
        QtMocHelpers::SignalData<void(GattServiceRemotePtr)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'gattCharacteristicAdded'
        QtMocHelpers::SignalData<void(GattCharacteristicRemotePtr)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'characteristicsChanged'
        QtMocHelpers::SignalData<void(QList<GattCharacteristicRemotePtr>)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'gattCharacteristicRemoved'
        QtMocHelpers::SignalData<void(GattCharacteristicRemotePtr)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'gattCharacteristicChanged'
        QtMocHelpers::SignalData<void(GattCharacteristicRemotePtr)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'uuidChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'primaryChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'handleChanged'
        QtMocHelpers::SignalData<void(quint16)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 18 },
        }}),
        // Signal 'includesChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'uuid'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'primary'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'device'
        QtMocHelpers::PropertyData<DevicePtr>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'includes'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(21, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'handle'
        QtMocHelpers::PropertyData<quint16>(18, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'characteristics'
        QtMocHelpers::PropertyData<QList<GattCharacteristicRemotePtr>>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GattServiceRemote, qt_meta_tag_ZN7BluezQt17GattServiceRemoteE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::GattServiceRemote::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt17GattServiceRemoteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt17GattServiceRemoteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt17GattServiceRemoteE_t>.metaTypes,
    nullptr
} };

void BluezQt::GattServiceRemote::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GattServiceRemote *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->serviceChanged((*reinterpret_cast<std::add_pointer_t<GattServiceRemotePtr>>(_a[1]))); break;
        case 1: _t->gattCharacteristicAdded((*reinterpret_cast<std::add_pointer_t<GattCharacteristicRemotePtr>>(_a[1]))); break;
        case 2: _t->characteristicsChanged((*reinterpret_cast<std::add_pointer_t<QList<GattCharacteristicRemotePtr>>>(_a[1]))); break;
        case 3: _t->gattCharacteristicRemoved((*reinterpret_cast<std::add_pointer_t<GattCharacteristicRemotePtr>>(_a[1]))); break;
        case 4: _t->gattCharacteristicChanged((*reinterpret_cast<std::add_pointer_t<GattCharacteristicRemotePtr>>(_a[1]))); break;
        case 5: _t->uuidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->primaryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->handleChanged((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 8: _t->includesChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GattServiceRemote::*)(GattServiceRemotePtr )>(_a, &GattServiceRemote::serviceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattServiceRemote::*)(GattCharacteristicRemotePtr )>(_a, &GattServiceRemote::gattCharacteristicAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattServiceRemote::*)(QList<GattCharacteristicRemotePtr> )>(_a, &GattServiceRemote::characteristicsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattServiceRemote::*)(GattCharacteristicRemotePtr )>(_a, &GattServiceRemote::gattCharacteristicRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattServiceRemote::*)(GattCharacteristicRemotePtr )>(_a, &GattServiceRemote::gattCharacteristicChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattServiceRemote::*)(const QString & )>(_a, &GattServiceRemote::uuidChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattServiceRemote::*)(bool )>(_a, &GattServiceRemote::primaryChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattServiceRemote::*)(quint16 )>(_a, &GattServiceRemote::handleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattServiceRemote::*)(const QList<QDBusObjectPath> & )>(_a, &GattServiceRemote::includesChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->uuid(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isPrimary(); break;
        case 2: *reinterpret_cast<DevicePtr*>(_v) = _t->device(); break;
        case 3: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->includes(); break;
        case 4: *reinterpret_cast<quint16*>(_v) = _t->handle(); break;
        case 5: *reinterpret_cast<QList<GattCharacteristicRemotePtr>*>(_v) = _t->characteristics(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setHandle(*reinterpret_cast<quint16*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::GattServiceRemote::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::GattServiceRemote::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt17GattServiceRemoteE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::GattServiceRemote::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::GattServiceRemote::serviceChanged(GattServiceRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::GattServiceRemote::gattCharacteristicAdded(GattCharacteristicRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluezQt::GattServiceRemote::characteristicsChanged(QList<GattCharacteristicRemotePtr> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluezQt::GattServiceRemote::gattCharacteristicRemoved(GattCharacteristicRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BluezQt::GattServiceRemote::gattCharacteristicChanged(GattCharacteristicRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BluezQt::GattServiceRemote::uuidChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluezQt::GattServiceRemote::primaryChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BluezQt::GattServiceRemote::handleChanged(quint16 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BluezQt::GattServiceRemote::includesChanged(const QList<QDBusObjectPath> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
