/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.bluez.GattDescriptor1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef BLUEZGATTDESCRIPTOR1_H
#define BLUEZGATTDESCRIPTOR1_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.bluez.GattDescriptor1
 */
class OrgBluezGattDescriptor1Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.bluez.GattDescriptor1"; }

public:
    OrgBluezGattDescriptor1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgBluezGattDescriptor1Interface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QByteArray> ReadValue(const QVariantMap &options)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(options);
        return asyncCallWithArgumentList(QStringLiteral("ReadValue"), argumentList);
    }

    inline QDBusPendingReply<> WriteValue(const QByteArray &value, const QVariantMap &options)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(value) << QVariant::fromValue(options);
        return asyncCallWithArgumentList(QStringLiteral("WriteValue"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace bluez {
    using GattDescriptor1 = ::OrgBluezGattDescriptor1Interface;
  }
}

#endif
