/****************************************************************************
** Meta object code from reading C++ file 'adapter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/adapter.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'adapter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt7AdapterE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::Adapter::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt7AdapterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::Adapter",
        "adapterRemoved",
        "",
        "AdapterPtr",
        "adapter",
        "adapterChanged",
        "nameChanged",
        "name",
        "systemNameChanged",
        "systemName",
        "adapterClassChanged",
        "adapterClass",
        "poweredChanged",
        "powered",
        "discoverableChanged",
        "discoverable",
        "discoverableTimeoutChanged",
        "timeout",
        "pairableChanged",
        "pairable",
        "pairableTimeoutChanged",
        "discoveringChanged",
        "discovering",
        "uuidsChanged",
        "uuids",
        "modaliasChanged",
        "modalias",
        "gattManagerChanged",
        "GattManagerPtr",
        "gattManager",
        "leAdvertisingManagerChanged",
        "LEAdvertisingManagerPtr",
        "leAdvertisingManager",
        "mediaChanged",
        "MediaPtr",
        "media",
        "deviceAdded",
        "DevicePtr",
        "device",
        "deviceRemoved",
        "deviceChanged",
        "ubi",
        "address",
        "discoverableTimeout",
        "pairableTimeout",
        "devices",
        "QList<DevicePtr>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'adapterRemoved'
        QtMocHelpers::SignalData<void(AdapterPtr)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'adapterChanged'
        QtMocHelpers::SignalData<void(AdapterPtr)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'systemNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'adapterClassChanged'
        QtMocHelpers::SignalData<void(quint32)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'poweredChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'discoverableChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'discoverableTimeoutChanged'
        QtMocHelpers::SignalData<void(quint32)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 17 },
        }}),
        // Signal 'pairableChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'pairableTimeoutChanged'
        QtMocHelpers::SignalData<void(quint32)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 17 },
        }}),
        // Signal 'discoveringChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'uuidsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 24 },
        }}),
        // Signal 'modaliasChanged'
        QtMocHelpers::SignalData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Signal 'gattManagerChanged'
        QtMocHelpers::SignalData<void(GattManagerPtr)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Signal 'leAdvertisingManagerChanged'
        QtMocHelpers::SignalData<void(LEAdvertisingManagerPtr)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Signal 'mediaChanged'
        QtMocHelpers::SignalData<void(MediaPtr)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(DevicePtr)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(DevicePtr)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void(DevicePtr)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ubi'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'address'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'systemName'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'adapterClass'
        QtMocHelpers::PropertyData<quint32>(11, QMetaType::UInt, QMC::DefaultPropertyFlags, 4),
        // property 'powered'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'discoverable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'discoverableTimeout'
        QtMocHelpers::PropertyData<quint32>(43, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'pairable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'pairableTimeout'
        QtMocHelpers::PropertyData<quint32>(44, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'discovering'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'uuids'
        QtMocHelpers::PropertyData<QStringList>(24, QMetaType::QStringList, QMC::DefaultPropertyFlags, 11),
        // property 'modalias'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'leAdvertisingManager'
        QtMocHelpers::PropertyData<LEAdvertisingManagerPtr>(32, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
        // property 'media'
        QtMocHelpers::PropertyData<MediaPtr>(35, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 15),
        // property 'devices'
        QtMocHelpers::PropertyData<QList<DevicePtr>>(45, 0x80000000 | 46, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Adapter, qt_meta_tag_ZN7BluezQt7AdapterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::Adapter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt7AdapterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt7AdapterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt7AdapterE_t>.metaTypes,
    nullptr
} };

void BluezQt::Adapter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Adapter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->adapterRemoved((*reinterpret_cast<std::add_pointer_t<AdapterPtr>>(_a[1]))); break;
        case 1: _t->adapterChanged((*reinterpret_cast<std::add_pointer_t<AdapterPtr>>(_a[1]))); break;
        case 2: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->systemNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->adapterClassChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 5: _t->poweredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->discoverableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->discoverableTimeoutChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 8: _t->pairableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->pairableTimeoutChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 10: _t->discoveringChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->uuidsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 12: _t->modaliasChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->gattManagerChanged((*reinterpret_cast<std::add_pointer_t<GattManagerPtr>>(_a[1]))); break;
        case 14: _t->leAdvertisingManagerChanged((*reinterpret_cast<std::add_pointer_t<LEAdvertisingManagerPtr>>(_a[1]))); break;
        case 15: _t->mediaChanged((*reinterpret_cast<std::add_pointer_t<MediaPtr>>(_a[1]))); break;
        case 16: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<DevicePtr>>(_a[1]))); break;
        case 17: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<DevicePtr>>(_a[1]))); break;
        case 18: _t->deviceChanged((*reinterpret_cast<std::add_pointer_t<DevicePtr>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(AdapterPtr )>(_a, &Adapter::adapterRemoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(AdapterPtr )>(_a, &Adapter::adapterChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const QString & )>(_a, &Adapter::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const QString & )>(_a, &Adapter::systemNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(quint32 )>(_a, &Adapter::adapterClassChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(bool )>(_a, &Adapter::poweredChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(bool )>(_a, &Adapter::discoverableChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(quint32 )>(_a, &Adapter::discoverableTimeoutChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(bool )>(_a, &Adapter::pairableChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(quint32 )>(_a, &Adapter::pairableTimeoutChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(bool )>(_a, &Adapter::discoveringChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const QStringList & )>(_a, &Adapter::uuidsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(const QString & )>(_a, &Adapter::modaliasChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(GattManagerPtr )>(_a, &Adapter::gattManagerChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(LEAdvertisingManagerPtr )>(_a, &Adapter::leAdvertisingManagerChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(MediaPtr )>(_a, &Adapter::mediaChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(DevicePtr )>(_a, &Adapter::deviceAdded, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(DevicePtr )>(_a, &Adapter::deviceRemoved, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Adapter::*)(DevicePtr )>(_a, &Adapter::deviceChanged, 18))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->ubi(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->address(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->systemName(); break;
        case 4: *reinterpret_cast<quint32*>(_v) = _t->adapterClass(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isPowered(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isDiscoverable(); break;
        case 7: *reinterpret_cast<quint32*>(_v) = _t->discoverableTimeout(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isPairable(); break;
        case 9: *reinterpret_cast<quint32*>(_v) = _t->pairableTimeout(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isDiscovering(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->uuids(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->modalias(); break;
        case 13: *reinterpret_cast<LEAdvertisingManagerPtr*>(_v) = _t->leAdvertisingManager(); break;
        case 14: *reinterpret_cast<MediaPtr*>(_v) = _t->media(); break;
        case 15: *reinterpret_cast<QList<DevicePtr>*>(_v) = _t->devices(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setPowered(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setDiscoverable(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setDiscoverableTimeout(*reinterpret_cast<quint32*>(_v)); break;
        case 8: _t->setPairable(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setPairableTimeout(*reinterpret_cast<quint32*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::Adapter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::Adapter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt7AdapterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::Adapter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::Adapter::adapterRemoved(AdapterPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::Adapter::adapterChanged(AdapterPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluezQt::Adapter::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluezQt::Adapter::systemNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BluezQt::Adapter::adapterClassChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BluezQt::Adapter::poweredChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluezQt::Adapter::discoverableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BluezQt::Adapter::discoverableTimeoutChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BluezQt::Adapter::pairableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void BluezQt::Adapter::pairableTimeoutChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void BluezQt::Adapter::discoveringChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void BluezQt::Adapter::uuidsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void BluezQt::Adapter::modaliasChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void BluezQt::Adapter::gattManagerChanged(GattManagerPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void BluezQt::Adapter::leAdvertisingManagerChanged(LEAdvertisingManagerPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void BluezQt::Adapter::mediaChanged(MediaPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void BluezQt::Adapter::deviceAdded(DevicePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void BluezQt::Adapter::deviceRemoved(DevicePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void BluezQt::Adapter::deviceChanged(DevicePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}
QT_WARNING_POP
