/****************************************************************************
** Meta object code from reading C++ file 'gattdescriptorremote.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/gattdescriptorremote.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gattdescriptorremote.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt20GattDescriptorRemoteE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::GattDescriptorRemote::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt20GattDescriptorRemoteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::GattDescriptorRemote",
        "descriptorChanged",
        "",
        "GattDescriptorRemotePtr",
        "descriptor",
        "uuidChanged",
        "uuid",
        "valueChanged",
        "value",
        "flagsChanged",
        "flags",
        "handleChanged",
        "handle",
        "readValue",
        "PendingCall*",
        "QVariantMap",
        "options",
        "writeValue",
        "ubi",
        "characteristic",
        "GattCharacteristicRemotePtr"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'descriptorChanged'
        QtMocHelpers::SignalData<void(GattDescriptorRemotePtr)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'uuidChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void(const QByteArray)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 8 },
        }}),
        // Signal 'flagsChanged'
        QtMocHelpers::SignalData<void(QStringList)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Signal 'handleChanged'
        QtMocHelpers::SignalData<void(quint16)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 12 },
        }}),
        // Slot 'readValue'
        QtMocHelpers::SlotData<PendingCall *(const QVariantMap &)>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'writeValue'
        QtMocHelpers::SlotData<PendingCall *(const QByteArray &, const QVariantMap &)>(17, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QByteArray, 8 }, { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ubi'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'uuid'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'value'
        QtMocHelpers::PropertyData<QByteArray>(8, QMetaType::QByteArray, QMC::DefaultPropertyFlags, 2),
        // property 'flags'
        QtMocHelpers::PropertyData<QStringList>(10, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'handle'
        QtMocHelpers::PropertyData<quint16>(12, QMetaType::UShort, QMC::DefaultPropertyFlags, 4),
        // property 'characteristic'
        QtMocHelpers::PropertyData<GattCharacteristicRemotePtr>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GattDescriptorRemote, qt_meta_tag_ZN7BluezQt20GattDescriptorRemoteE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::GattDescriptorRemote::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt20GattDescriptorRemoteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt20GattDescriptorRemoteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt20GattDescriptorRemoteE_t>.metaTypes,
    nullptr
} };

void BluezQt::GattDescriptorRemote::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GattDescriptorRemote *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->descriptorChanged((*reinterpret_cast<std::add_pointer_t<GattDescriptorRemotePtr>>(_a[1]))); break;
        case 1: _t->uuidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->valueChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 3: _t->flagsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->handleChanged((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 5: { PendingCall* _r = _t->readValue((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 6: { PendingCall* _r = _t->writeValue((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GattDescriptorRemote::*)(GattDescriptorRemotePtr )>(_a, &GattDescriptorRemote::descriptorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattDescriptorRemote::*)(const QString & )>(_a, &GattDescriptorRemote::uuidChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattDescriptorRemote::*)(const QByteArray )>(_a, &GattDescriptorRemote::valueChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattDescriptorRemote::*)(QStringList )>(_a, &GattDescriptorRemote::flagsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattDescriptorRemote::*)(quint16 )>(_a, &GattDescriptorRemote::handleChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->ubi(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->uuid(); break;
        case 2: *reinterpret_cast<QByteArray*>(_v) = _t->value(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->flags(); break;
        case 4: *reinterpret_cast<quint16*>(_v) = _t->handle(); break;
        case 5: *reinterpret_cast<GattCharacteristicRemotePtr*>(_v) = _t->characteristic(); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::GattDescriptorRemote::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::GattDescriptorRemote::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt20GattDescriptorRemoteE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::GattDescriptorRemote::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::GattDescriptorRemote::descriptorChanged(GattDescriptorRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::GattDescriptorRemote::uuidChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluezQt::GattDescriptorRemote::valueChanged(const QByteArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluezQt::GattDescriptorRemote::flagsChanged(QStringList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BluezQt::GattDescriptorRemote::handleChanged(quint16 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
