/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<bluezqtextensionplugin.h>)
#  include <bluezqtextensionplugin.h>
#endif
#if __has_include(<declarativeadapter.h>)
#  include <declarativeadapter.h>
#endif
#if __has_include(<declarativebattery.h>)
#  include <declarativebattery.h>
#endif
#if __has_include(<declarativedevice.h>)
#  include <declarativedevice.h>
#endif
#if __has_include(<declarativedevicesmodel.h>)
#  include <declarativedevicesmodel.h>
#endif
#if __has_include(<declarativeinput.h>)
#  include <declarativeinput.h>
#endif
#if __has_include(<declarativemanager.h>)
#  include <declarativemanager.h>
#endif
#if __has_include(<declarativemediaplayer.h>)
#  include <declarativemediaplayer.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_bluezqt()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<BluezQt::Manager *>().id();
    qmlRegisterTypesAndRevisions<DeclarativeAdapter>("org.kde.bluezqt", 1);
    qmlRegisterTypesAndRevisions<DeclarativeBattery>("org.kde.bluezqt", 1);
    qmlRegisterTypesAndRevisions<DeclarativeDevice>("org.kde.bluezqt", 1);
    qmlRegisterTypesAndRevisions<DeclarativeDevicesModel>("org.kde.bluezqt", 1);
    qmlRegisterTypesAndRevisions<DeclarativeInput>("org.kde.bluezqt", 1);
    qmlRegisterTypesAndRevisions<DeclarativeManager>("org.kde.bluezqt", 1);
    qmlRegisterTypesAndRevisions<DeclarativeMediaPlayer>("org.kde.bluezqt", 1);
    qmlRegisterTypesAndRevisions<PendingCallForeign>("org.kde.bluezqt", 1);
    qmlRegisterEnum<BluezQt::PendingCall::Error>("BluezQt::PendingCall::Error");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<RfkillForeign>("org.kde.bluezqt", 1);
    qmlRegisterEnum<BluezQt::Rfkill::State>("BluezQt::Rfkill::State");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.bluezqt", 1, 0);
}

static const QQmlModuleRegistration orgkdebluezqtRegistration("org.kde.bluezqt", qml_register_types_org_kde_bluezqt);
