/****************************************************************************
** Meta object code from reading C++ file 'mediatransport.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/mediatransport.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediatransport.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt14MediaTransportE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::MediaTransport::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt14MediaTransportE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::MediaTransport",
        "stateChanged",
        "",
        "State",
        "state",
        "volumeChanged",
        "volume",
        "acquire",
        "TPendingCall<QDBusUnixFileDescriptor,uint16_t,uint16_t>*",
        "tryAcquire",
        "release",
        "TPendingCall<void>*",
        "Idle",
        "Pending",
        "Active"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(enum State)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void(quint16)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 6 },
        }}),
        // Slot 'acquire'
        QtMocHelpers::SlotData<TPendingCall<QDBusUnixFileDescriptor,uint16_t,uint16_t> *()>(7, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'tryAcquire'
        QtMocHelpers::SlotData<TPendingCall<QDBusUnixFileDescriptor,uint16_t,uint16_t> *()>(9, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'release'
        QtMocHelpers::SlotData<TPendingCall<void> *()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'volume'
        QtMocHelpers::PropertyData<quint16>(6, QMetaType::UShort, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(3, 3, QMC::EnumIsScoped).add({
            {   12, State::Idle },
            {   13, State::Pending },
            {   14, State::Active },
        }),
    };
    return QtMocHelpers::metaObjectData<MediaTransport, qt_meta_tag_ZN7BluezQt14MediaTransportE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::MediaTransport::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt14MediaTransportE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt14MediaTransportE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt14MediaTransportE_t>.metaTypes,
    nullptr
} };

void BluezQt::MediaTransport::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MediaTransport *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<enum State>>(_a[1]))); break;
        case 1: _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 2: { TPendingCall<QDBusUnixFileDescriptor,uint16_t,uint16_t>* _r = _t->acquire();
            if (_a[0]) *reinterpret_cast<TPendingCall<QDBusUnixFileDescriptor,uint16_t,uint16_t>**>(_a[0]) = std::move(_r); }  break;
        case 3: { TPendingCall<QDBusUnixFileDescriptor,uint16_t,uint16_t>* _r = _t->tryAcquire();
            if (_a[0]) *reinterpret_cast<TPendingCall<QDBusUnixFileDescriptor,uint16_t,uint16_t>**>(_a[0]) = std::move(_r); }  break;
        case 4: { TPendingCall<void>* _r = _t->release();
            if (_a[0]) *reinterpret_cast<TPendingCall<void>**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MediaTransport::*)(State )>(_a, &MediaTransport::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaTransport::*)(quint16 )>(_a, &MediaTransport::volumeChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast<quint16*>(_v) = _t->volume(); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::MediaTransport::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::MediaTransport::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt14MediaTransportE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::MediaTransport::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::MediaTransport::stateChanged(State _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::MediaTransport::volumeChanged(quint16 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
