/****************************************************************************
** Meta object code from reading C++ file 'declarativemanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../bluez-qt-6.25.0/src/imports/declarativemanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativemanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18DeclarativeManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeManager::qt_create_metaobjectdata<qt_meta_tag_ZN18DeclarativeManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeManager",
        "QML.Element",
        "Manager",
        "QML.Singleton",
        "true",
        "initFinished",
        "",
        "initError",
        "errorText",
        "adapterAdded",
        "DeclarativeAdapter*",
        "adapter",
        "adapterRemoved",
        "adapterChanged",
        "deviceAdded",
        "DeclarativeDevice*",
        "device",
        "deviceRemoved",
        "deviceChanged",
        "usableAdapterChanged",
        "adaptersChanged",
        "QQmlListProperty<DeclarativeAdapter>",
        "adapters",
        "devicesChanged",
        "QQmlListProperty<DeclarativeDevice>",
        "devices",
        "connectedDevicesChanged",
        "adapterForAddress",
        "address",
        "adapterForUbi",
        "ubi",
        "deviceForAddress",
        "deviceForUbi",
        "initJobResult",
        "BluezQt::InitManagerJob*",
        "job",
        "slotAdapterAdded",
        "BluezQt::AdapterPtr",
        "slotAdapterRemoved",
        "slotDeviceAdded",
        "BluezQt::DevicePtr",
        "slotDeviceRemoved",
        "slotUsableAdapterChanged",
        "slotDeviceConnectedChanged",
        "usableAdapter",
        "connectedDevices"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'initFinished'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initError'
        QtMocHelpers::SignalData<void(const QString &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'adapterAdded'
        QtMocHelpers::SignalData<void(DeclarativeAdapter *)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'adapterRemoved'
        QtMocHelpers::SignalData<void(DeclarativeAdapter *)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'adapterChanged'
        QtMocHelpers::SignalData<void(DeclarativeAdapter *)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(DeclarativeDevice *)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(DeclarativeDevice *)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void(DeclarativeDevice *)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'usableAdapterChanged'
        QtMocHelpers::SignalData<void(DeclarativeAdapter *)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'adaptersChanged'
        QtMocHelpers::SignalData<void(QQmlListProperty<DeclarativeAdapter>)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'devicesChanged'
        QtMocHelpers::SignalData<void(QQmlListProperty<DeclarativeDevice>)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Signal 'connectedDevicesChanged'
        QtMocHelpers::SignalData<void(QQmlListProperty<DeclarativeDevice>)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'adapterForAddress'
        QtMocHelpers::SlotData<DeclarativeAdapter *(const QString &) const>(27, 6, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'adapterForUbi'
        QtMocHelpers::SlotData<DeclarativeAdapter *(const QString &) const>(29, 6, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'deviceForAddress'
        QtMocHelpers::SlotData<DeclarativeDevice *(const QString &) const>(31, 6, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'deviceForUbi'
        QtMocHelpers::SlotData<DeclarativeDevice *(const QString &) const>(32, 6, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'initJobResult'
        QtMocHelpers::SlotData<void(BluezQt::InitManagerJob *)>(33, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'slotAdapterAdded'
        QtMocHelpers::SlotData<void(BluezQt::AdapterPtr)>(36, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 11 },
        }}),
        // Slot 'slotAdapterRemoved'
        QtMocHelpers::SlotData<void(BluezQt::AdapterPtr)>(38, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 11 },
        }}),
        // Slot 'slotDeviceAdded'
        QtMocHelpers::SlotData<void(BluezQt::DevicePtr)>(39, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 16 },
        }}),
        // Slot 'slotDeviceRemoved'
        QtMocHelpers::SlotData<void(BluezQt::DevicePtr)>(41, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 16 },
        }}),
        // Slot 'slotUsableAdapterChanged'
        QtMocHelpers::SlotData<void(BluezQt::AdapterPtr)>(42, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 11 },
        }}),
        // Slot 'slotDeviceConnectedChanged'
        QtMocHelpers::SlotData<void()>(43, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'usableAdapter'
        QtMocHelpers::PropertyData<DeclarativeAdapter*>(44, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'adapters'
        QtMocHelpers::PropertyData<QQmlListProperty<DeclarativeAdapter>>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'devices'
        QtMocHelpers::PropertyData<QQmlListProperty<DeclarativeDevice>>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'connectedDevices'
        QtMocHelpers::PropertyData<QQmlListProperty<DeclarativeDevice>>(45, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeManager::staticMetaObject = { {
    QMetaObject::SuperData::link<BluezQt::Manager::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DeclarativeManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DeclarativeManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18DeclarativeManagerE_t>.metaTypes,
    nullptr
} };

void DeclarativeManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initFinished(); break;
        case 1: _t->initError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->adapterAdded((*reinterpret_cast<std::add_pointer_t<DeclarativeAdapter*>>(_a[1]))); break;
        case 3: _t->adapterRemoved((*reinterpret_cast<std::add_pointer_t<DeclarativeAdapter*>>(_a[1]))); break;
        case 4: _t->adapterChanged((*reinterpret_cast<std::add_pointer_t<DeclarativeAdapter*>>(_a[1]))); break;
        case 5: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<DeclarativeDevice*>>(_a[1]))); break;
        case 6: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<DeclarativeDevice*>>(_a[1]))); break;
        case 7: _t->deviceChanged((*reinterpret_cast<std::add_pointer_t<DeclarativeDevice*>>(_a[1]))); break;
        case 8: _t->usableAdapterChanged((*reinterpret_cast<std::add_pointer_t<DeclarativeAdapter*>>(_a[1]))); break;
        case 9: _t->adaptersChanged((*reinterpret_cast<std::add_pointer_t<QQmlListProperty<DeclarativeAdapter>>>(_a[1]))); break;
        case 10: _t->devicesChanged((*reinterpret_cast<std::add_pointer_t<QQmlListProperty<DeclarativeDevice>>>(_a[1]))); break;
        case 11: _t->connectedDevicesChanged((*reinterpret_cast<std::add_pointer_t<QQmlListProperty<DeclarativeDevice>>>(_a[1]))); break;
        case 12: { DeclarativeAdapter* _r = _t->adapterForAddress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeAdapter**>(_a[0]) = std::move(_r); }  break;
        case 13: { DeclarativeAdapter* _r = _t->adapterForUbi((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeAdapter**>(_a[0]) = std::move(_r); }  break;
        case 14: { DeclarativeDevice* _r = _t->deviceForAddress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeDevice**>(_a[0]) = std::move(_r); }  break;
        case 15: { DeclarativeDevice* _r = _t->deviceForUbi((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeDevice**>(_a[0]) = std::move(_r); }  break;
        case 16: _t->initJobResult((*reinterpret_cast<std::add_pointer_t<BluezQt::InitManagerJob*>>(_a[1]))); break;
        case 17: _t->slotAdapterAdded((*reinterpret_cast<std::add_pointer_t<BluezQt::AdapterPtr>>(_a[1]))); break;
        case 18: _t->slotAdapterRemoved((*reinterpret_cast<std::add_pointer_t<BluezQt::AdapterPtr>>(_a[1]))); break;
        case 19: _t->slotDeviceAdded((*reinterpret_cast<std::add_pointer_t<BluezQt::DevicePtr>>(_a[1]))); break;
        case 20: _t->slotDeviceRemoved((*reinterpret_cast<std::add_pointer_t<BluezQt::DevicePtr>>(_a[1]))); break;
        case 21: _t->slotUsableAdapterChanged((*reinterpret_cast<std::add_pointer_t<BluezQt::AdapterPtr>>(_a[1]))); break;
        case 22: _t->slotDeviceConnectedChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)()>(_a, &DeclarativeManager::initFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(const QString & )>(_a, &DeclarativeManager::initError, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(DeclarativeAdapter * )>(_a, &DeclarativeManager::adapterAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(DeclarativeAdapter * )>(_a, &DeclarativeManager::adapterRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(DeclarativeAdapter * )>(_a, &DeclarativeManager::adapterChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(DeclarativeDevice * )>(_a, &DeclarativeManager::deviceAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(DeclarativeDevice * )>(_a, &DeclarativeManager::deviceRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(DeclarativeDevice * )>(_a, &DeclarativeManager::deviceChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(DeclarativeAdapter * )>(_a, &DeclarativeManager::usableAdapterChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(QQmlListProperty<DeclarativeAdapter> )>(_a, &DeclarativeManager::adaptersChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(QQmlListProperty<DeclarativeDevice> )>(_a, &DeclarativeManager::devicesChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeManager::*)(QQmlListProperty<DeclarativeDevice> )>(_a, &DeclarativeManager::connectedDevicesChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<DeclarativeAdapter**>(_v) = _t->usableAdapter(); break;
        case 1: *reinterpret_cast<QQmlListProperty<DeclarativeAdapter>*>(_v) = _t->declarativeAdapters(); break;
        case 2: *reinterpret_cast<QQmlListProperty<DeclarativeDevice>*>(_v) = _t->declarativeDevices(); break;
        case 3: *reinterpret_cast<QQmlListProperty<DeclarativeDevice>*>(_v) = _t->declarativeConnectedDevices(); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DeclarativeManagerE_t>.strings))
        return static_cast<void*>(this);
    return BluezQt::Manager::qt_metacast(_clname);
}

int DeclarativeManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BluezQt::Manager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeManager::initFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DeclarativeManager::initError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeManager::adapterAdded(DeclarativeAdapter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeManager::adapterRemoved(DeclarativeAdapter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeclarativeManager::adapterChanged(DeclarativeAdapter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DeclarativeManager::deviceAdded(DeclarativeDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DeclarativeManager::deviceRemoved(DeclarativeDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DeclarativeManager::deviceChanged(DeclarativeDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DeclarativeManager::usableAdapterChanged(DeclarativeAdapter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DeclarativeManager::adaptersChanged(QQmlListProperty<DeclarativeAdapter> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DeclarativeManager::devicesChanged(QQmlListProperty<DeclarativeDevice> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DeclarativeManager::connectedDevicesChanged(QQmlListProperty<DeclarativeDevice> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
