/****************************************************************************
** Meta object code from reading C++ file 'gattcharacteristicadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/gattcharacteristicadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gattcharacteristicadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt25GattCharacteristicAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::GattCharacteristicAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt25GattCharacteristicAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::GattCharacteristicAdaptor",
        "D-Bus Interface",
        "org.bluez.GattCharacteristic1",
        "ReadValue",
        "",
        "QVariantMap",
        "options",
        "WriteValue",
        "value",
        "StartNotify",
        "StopNotify",
        "UUID",
        "Service",
        "QDBusObjectPath",
        "Flags"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'ReadValue'
        QtMocHelpers::SlotData<QByteArray(const QVariantMap &)>(3, 4, QMC::AccessPublic, QMetaType::QByteArray, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'WriteValue'
        QtMocHelpers::SlotData<void(const QByteArray &, const QVariantMap &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 8 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'StartNotify'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'StopNotify'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'UUID'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Service'
        QtMocHelpers::PropertyData<QDBusObjectPath>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Flags'
        QtMocHelpers::PropertyData<QStringList>(14, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<GattCharacteristicAdaptor, qt_meta_tag_ZN7BluezQt25GattCharacteristicAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BluezQt::GattCharacteristicAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt25GattCharacteristicAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt25GattCharacteristicAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt25GattCharacteristicAdaptorE_t>.metaTypes,
    nullptr
} };

void BluezQt::GattCharacteristicAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GattCharacteristicAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QByteArray _r = _t->ReadValue((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->WriteValue((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 2: _t->StartNotify(); break;
        case 3: _t->StopNotify(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->uuid(); break;
        case 1: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->service(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->flags(); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::GattCharacteristicAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::GattCharacteristicAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt25GattCharacteristicAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int BluezQt::GattCharacteristicAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
