/****************************************************************************
** Meta object code from reading C++ file 'obexfiletransfer1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "obexfiletransfer1.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'obexfiletransfer1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN34OrgBluezObexFileTransfer1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgBluezObexFileTransfer1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN34OrgBluezObexFileTransfer1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgBluezObexFileTransfer1Interface",
        "ChangeFolder",
        "QDBusPendingReply<>",
        "",
        "folder",
        "CopyFile",
        "sourcefile",
        "targetfile",
        "CreateFolder",
        "Delete",
        "file",
        "GetFile",
        "QDBusPendingReply<QDBusObjectPath,QVariantMap>",
        "QDBusReply<QDBusObjectPath>",
        "QVariantMap&",
        "properties",
        "ListFolder",
        "QDBusPendingReply<QVariantMapList>",
        "MoveFile",
        "PutFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'ChangeFolder'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'CopyFile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'CreateFolder'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(9, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'GetFile'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath,QVariantMap>(const QString &, const QString &)>(11, 3, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'GetFile'
        QtMocHelpers::SlotData<QDBusReply<QDBusObjectPath>(const QString &, const QString &, QVariantMap &)>(11, 3, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 6 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'ListFolder'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMapList>()>(16, 3, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'MoveFile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(18, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'PutFile'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath,QVariantMap>(const QString &, const QString &)>(19, 3, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'PutFile'
        QtMocHelpers::SlotData<QDBusReply<QDBusObjectPath>(const QString &, const QString &, QVariantMap &)>(19, 3, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgBluezObexFileTransfer1Interface, qt_meta_tag_ZN34OrgBluezObexFileTransfer1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgBluezObexFileTransfer1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgBluezObexFileTransfer1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgBluezObexFileTransfer1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN34OrgBluezObexFileTransfer1InterfaceE_t>.metaTypes,
    nullptr
} };

void OrgBluezObexFileTransfer1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgBluezObexFileTransfer1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->ChangeFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->CopyFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->CreateFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QDBusObjectPath,QVariantMap> _r = _t->GetFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath,QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusReply<QDBusObjectPath> _r = _t->GetFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QVariantMapList> _r = _t->ListFolder();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMapList>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->MoveFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<QDBusObjectPath,QVariantMap> _r = _t->PutFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath,QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusReply<QDBusObjectPath> _r = _t->PutFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *OrgBluezObexFileTransfer1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgBluezObexFileTransfer1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgBluezObexFileTransfer1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgBluezObexFileTransfer1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
