/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.bluez.MediaTransport1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef BLUEZMEDIATRANSPORT1_H
#define BLUEZMEDIATRANSPORT1_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.bluez.MediaTransport1
 */
class OrgBluezMediaTransport1Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.bluez.MediaTransport1"; }

public:
    OrgBluezMediaTransport1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgBluezMediaTransport1Interface();

    Q_PROPERTY(uchar Codec READ codec)
    inline uchar codec() const
    { return qvariant_cast< uchar >(property("Codec")); }

    Q_PROPERTY(QByteArray Configuration READ configuration)
    inline QByteArray configuration() const
    { return qvariant_cast< QByteArray >(property("Configuration")); }

    Q_PROPERTY(ushort Delay READ delay)
    inline ushort delay() const
    { return qvariant_cast< ushort >(property("Delay")); }

    Q_PROPERTY(QDBusObjectPath Device READ device)
    inline QDBusObjectPath device() const
    { return qvariant_cast< QDBusObjectPath >(property("Device")); }

    Q_PROPERTY(QString State READ state)
    inline QString state() const
    { return qvariant_cast< QString >(property("State")); }

    Q_PROPERTY(QString UUID READ uUID)
    inline QString uUID() const
    { return qvariant_cast< QString >(property("UUID")); }

    Q_PROPERTY(ushort Volume READ volume WRITE setVolume)
    inline ushort volume() const
    { return qvariant_cast< ushort >(property("Volume")); }
    inline void setVolume(ushort value)
    { setProperty("Volume", QVariant::fromValue(value)); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QDBusUnixFileDescriptor, ushort, ushort> Acquire()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Acquire"), argumentList);
    }
    inline QDBusReply<QDBusUnixFileDescriptor> Acquire(ushort &mtu_r, ushort &mtu_w)
    {
        QList<QVariant> argumentList;
        QDBusMessage reply = callWithArgumentList(QDBus::Block, QStringLiteral("Acquire"), argumentList);
        if (reply.type() == QDBusMessage::ReplyMessage && reply.arguments().size() == 3) {
            mtu_r = qdbus_cast<ushort>(reply.arguments().at(1));
            mtu_w = qdbus_cast<ushort>(reply.arguments().at(2));
        }
        return reply;
    }

    inline QDBusPendingReply<> Release()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Release"), argumentList);
    }

    inline QDBusPendingReply<QDBusUnixFileDescriptor, ushort, ushort> TryAcquire()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("TryAcquire"), argumentList);
    }
    inline QDBusReply<QDBusUnixFileDescriptor> TryAcquire(ushort &mtu_r, ushort &mtu_w)
    {
        QList<QVariant> argumentList;
        QDBusMessage reply = callWithArgumentList(QDBus::Block, QStringLiteral("TryAcquire"), argumentList);
        if (reply.type() == QDBusMessage::ReplyMessage && reply.arguments().size() == 3) {
            mtu_r = qdbus_cast<ushort>(reply.arguments().at(1));
            mtu_w = qdbus_cast<ushort>(reply.arguments().at(2));
        }
        return reply;
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace bluez {
    using MediaTransport1 = ::OrgBluezMediaTransport1Interface;
  }
}

#endif
