/****************************************************************************
** Meta object code from reading C++ file 'mediaplayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/mediaplayer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediaplayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt11MediaPlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::MediaPlayer::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt11MediaPlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::MediaPlayer",
        "nameChanged",
        "",
        "name",
        "equalizerChanged",
        "Equalizer",
        "equalizer",
        "repeatChanged",
        "Repeat",
        "repeat",
        "shuffleChanged",
        "Shuffle",
        "shuffle",
        "statusChanged",
        "Status",
        "status",
        "trackChanged",
        "MediaPlayerTrack",
        "track",
        "positionChanged",
        "position",
        "play",
        "PendingCall*",
        "pause",
        "stop",
        "next",
        "previous",
        "fastForward",
        "rewind",
        "EqualizerOn",
        "EqualizerOff",
        "RepeatOff",
        "RepeatSingleTrack",
        "RepeatAllTracks",
        "RepeatGroup",
        "ShuffleOff",
        "ShuffleAllTracks",
        "ShuffleGroup",
        "Playing",
        "Stopped",
        "Paused",
        "ForwardSeek",
        "ReverseSeek",
        "Error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'equalizerChanged'
        QtMocHelpers::SignalData<void(enum Equalizer)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'repeatChanged'
        QtMocHelpers::SignalData<void(enum Repeat)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'shuffleChanged'
        QtMocHelpers::SignalData<void(enum Shuffle)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(enum Status)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'trackChanged'
        QtMocHelpers::SignalData<void(MediaPlayerTrack)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(quint32)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 20 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<PendingCall *()>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'pause'
        QtMocHelpers::SlotData<PendingCall *()>(23, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'stop'
        QtMocHelpers::SlotData<PendingCall *()>(24, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'next'
        QtMocHelpers::SlotData<PendingCall *()>(25, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'previous'
        QtMocHelpers::SlotData<PendingCall *()>(26, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'fastForward'
        QtMocHelpers::SlotData<PendingCall *()>(27, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'rewind'
        QtMocHelpers::SlotData<PendingCall *()>(28, 2, QMC::AccessPublic, 0x80000000 | 22),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'equalizer'
        QtMocHelpers::PropertyData<enum Equalizer>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'repeat'
        QtMocHelpers::PropertyData<enum Repeat>(9, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'shuffle'
        QtMocHelpers::PropertyData<enum Shuffle>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'track'
        QtMocHelpers::PropertyData<MediaPlayerTrack>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'position'
        QtMocHelpers::PropertyData<quint32>(20, QMetaType::UInt, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Equalizer'
        QtMocHelpers::EnumData<enum Equalizer>(5, 5, QMC::EnumFlags{}).add({
            {   29, Equalizer::EqualizerOn },
            {   30, Equalizer::EqualizerOff },
        }),
        // enum 'Repeat'
        QtMocHelpers::EnumData<enum Repeat>(8, 8, QMC::EnumFlags{}).add({
            {   31, Repeat::RepeatOff },
            {   32, Repeat::RepeatSingleTrack },
            {   33, Repeat::RepeatAllTracks },
            {   34, Repeat::RepeatGroup },
        }),
        // enum 'Shuffle'
        QtMocHelpers::EnumData<enum Shuffle>(11, 11, QMC::EnumFlags{}).add({
            {   35, Shuffle::ShuffleOff },
            {   36, Shuffle::ShuffleAllTracks },
            {   37, Shuffle::ShuffleGroup },
        }),
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(14, 14, QMC::EnumFlags{}).add({
            {   38, Status::Playing },
            {   39, Status::Stopped },
            {   40, Status::Paused },
            {   41, Status::ForwardSeek },
            {   42, Status::ReverseSeek },
            {   43, Status::Error },
        }),
    };
    return QtMocHelpers::metaObjectData<MediaPlayer, qt_meta_tag_ZN7BluezQt11MediaPlayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::MediaPlayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt11MediaPlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt11MediaPlayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt11MediaPlayerE_t>.metaTypes,
    nullptr
} };

void BluezQt::MediaPlayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MediaPlayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->equalizerChanged((*reinterpret_cast<std::add_pointer_t<enum Equalizer>>(_a[1]))); break;
        case 2: _t->repeatChanged((*reinterpret_cast<std::add_pointer_t<enum Repeat>>(_a[1]))); break;
        case 3: _t->shuffleChanged((*reinterpret_cast<std::add_pointer_t<enum Shuffle>>(_a[1]))); break;
        case 4: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<enum Status>>(_a[1]))); break;
        case 5: _t->trackChanged((*reinterpret_cast<std::add_pointer_t<MediaPlayerTrack>>(_a[1]))); break;
        case 6: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 7: { PendingCall* _r = _t->play();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 8: { PendingCall* _r = _t->pause();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 9: { PendingCall* _r = _t->stop();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 10: { PendingCall* _r = _t->next();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 11: { PendingCall* _r = _t->previous();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 12: { PendingCall* _r = _t->fastForward();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 13: { PendingCall* _r = _t->rewind();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer::*)(const QString & )>(_a, &MediaPlayer::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer::*)(Equalizer )>(_a, &MediaPlayer::equalizerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer::*)(Repeat )>(_a, &MediaPlayer::repeatChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer::*)(Shuffle )>(_a, &MediaPlayer::shuffleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer::*)(Status )>(_a, &MediaPlayer::statusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer::*)(MediaPlayerTrack )>(_a, &MediaPlayer::trackChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayer::*)(quint32 )>(_a, &MediaPlayer::positionChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<enum Equalizer*>(_v) = _t->equalizer(); break;
        case 2: *reinterpret_cast<enum Repeat*>(_v) = _t->repeat(); break;
        case 3: *reinterpret_cast<enum Shuffle*>(_v) = _t->shuffle(); break;
        case 4: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 5: *reinterpret_cast<MediaPlayerTrack*>(_v) = _t->track(); break;
        case 6: *reinterpret_cast<quint32*>(_v) = _t->position(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setEqualizer(*reinterpret_cast<enum Equalizer*>(_v)); break;
        case 2: _t->setRepeat(*reinterpret_cast<enum Repeat*>(_v)); break;
        case 3: _t->setShuffle(*reinterpret_cast<enum Shuffle*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::MediaPlayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::MediaPlayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt11MediaPlayerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::MediaPlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::MediaPlayer::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::MediaPlayer::equalizerChanged(Equalizer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluezQt::MediaPlayer::repeatChanged(Repeat _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluezQt::MediaPlayer::shuffleChanged(Shuffle _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BluezQt::MediaPlayer::statusChanged(Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BluezQt::MediaPlayer::trackChanged(MediaPlayerTrack _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluezQt::MediaPlayer::positionChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
