/****************************************************************************
** Meta object code from reading C++ file 'gattcharacteristicremote.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/gattcharacteristicremote.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gattcharacteristicremote.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt24GattCharacteristicRemoteE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::GattCharacteristicRemote::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt24GattCharacteristicRemoteE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::GattCharacteristicRemote",
        "characteristicChanged",
        "",
        "GattCharacteristicRemotePtr",
        "characteristic",
        "gattDescriptorAdded",
        "GattDescriptorRemotePtr",
        "descriptor",
        "descriptorsChanged",
        "QList<GattDescriptorRemotePtr>",
        "descriptors",
        "gattDescriptorRemoved",
        "gattDescriptorChanged",
        "uuidChanged",
        "uuid",
        "valueChanged",
        "value",
        "writeAcquiredChanged",
        "writeAcquired",
        "notifyAcquiredChanged",
        "notifyAcquired",
        "notifyingChanged",
        "notifying",
        "flagsChanged",
        "flags",
        "handleChanged",
        "handle",
        "MTUChanged",
        "MTU",
        "readValue",
        "PendingCall*",
        "QVariantMap",
        "options",
        "writeValue",
        "startNotify",
        "stopNotify",
        "confirm",
        "ubi",
        "service",
        "GattServiceRemotePtr"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'characteristicChanged'
        QtMocHelpers::SignalData<void(GattCharacteristicRemotePtr)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'gattDescriptorAdded'
        QtMocHelpers::SignalData<void(GattDescriptorRemotePtr)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'descriptorsChanged'
        QtMocHelpers::SignalData<void(QList<GattDescriptorRemotePtr>)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'gattDescriptorRemoved'
        QtMocHelpers::SignalData<void(GattDescriptorRemotePtr)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'gattDescriptorChanged'
        QtMocHelpers::SignalData<void(GattDescriptorRemotePtr)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'uuidChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void(const QByteArray)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 16 },
        }}),
        // Signal 'writeAcquiredChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'notifyAcquiredChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Signal 'notifyingChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'flagsChanged'
        QtMocHelpers::SignalData<void(QStringList)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 24 },
        }}),
        // Signal 'handleChanged'
        QtMocHelpers::SignalData<void(quint16)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 26 },
        }}),
        // Signal 'MTUChanged'
        QtMocHelpers::SignalData<void(quint16)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 28 },
        }}),
        // Slot 'readValue'
        QtMocHelpers::SlotData<PendingCall *(const QVariantMap &)>(29, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'writeValue'
        QtMocHelpers::SlotData<PendingCall *(const QByteArray &, const QVariantMap &)>(33, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::QByteArray, 16 }, { 0x80000000 | 31, 32 },
        }}),
        // Slot 'startNotify'
        QtMocHelpers::SlotData<PendingCall *()>(34, 2, QMC::AccessPublic, 0x80000000 | 30),
        // Slot 'stopNotify'
        QtMocHelpers::SlotData<PendingCall *()>(35, 2, QMC::AccessPublic, 0x80000000 | 30),
        // Slot 'confirm'
        QtMocHelpers::SlotData<PendingCall *()>(36, 2, QMC::AccessPublic, 0x80000000 | 30),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ubi'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'uuid'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'value'
        QtMocHelpers::PropertyData<QByteArray>(16, QMetaType::QByteArray, QMC::DefaultPropertyFlags, 6),
        // property 'writeAcquired'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'notifyAcquired'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'notifying'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'flags'
        QtMocHelpers::PropertyData<QStringList>(24, QMetaType::QStringList, QMC::DefaultPropertyFlags, 10),
        // property 'handle'
        QtMocHelpers::PropertyData<quint16>(26, QMetaType::UShort, QMC::DefaultPropertyFlags, 11),
        // property 'MTU'
        QtMocHelpers::PropertyData<quint16>(28, QMetaType::UShort, QMC::DefaultPropertyFlags, 12),
        // property 'service'
        QtMocHelpers::PropertyData<GattServiceRemotePtr>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'descriptors'
        QtMocHelpers::PropertyData<QList<GattDescriptorRemotePtr>>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GattCharacteristicRemote, qt_meta_tag_ZN7BluezQt24GattCharacteristicRemoteE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::GattCharacteristicRemote::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt24GattCharacteristicRemoteE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt24GattCharacteristicRemoteE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt24GattCharacteristicRemoteE_t>.metaTypes,
    nullptr
} };

void BluezQt::GattCharacteristicRemote::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GattCharacteristicRemote *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->characteristicChanged((*reinterpret_cast<std::add_pointer_t<GattCharacteristicRemotePtr>>(_a[1]))); break;
        case 1: _t->gattDescriptorAdded((*reinterpret_cast<std::add_pointer_t<GattDescriptorRemotePtr>>(_a[1]))); break;
        case 2: _t->descriptorsChanged((*reinterpret_cast<std::add_pointer_t<QList<GattDescriptorRemotePtr>>>(_a[1]))); break;
        case 3: _t->gattDescriptorRemoved((*reinterpret_cast<std::add_pointer_t<GattDescriptorRemotePtr>>(_a[1]))); break;
        case 4: _t->gattDescriptorChanged((*reinterpret_cast<std::add_pointer_t<GattDescriptorRemotePtr>>(_a[1]))); break;
        case 5: _t->uuidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->valueChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 7: _t->writeAcquiredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->notifyAcquiredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->notifyingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->flagsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 11: _t->handleChanged((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 12: _t->MTUChanged((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 13: { PendingCall* _r = _t->readValue((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 14: { PendingCall* _r = _t->writeValue((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 15: { PendingCall* _r = _t->startNotify();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 16: { PendingCall* _r = _t->stopNotify();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 17: { PendingCall* _r = _t->confirm();
            if (_a[0]) *reinterpret_cast<PendingCall**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(GattCharacteristicRemotePtr )>(_a, &GattCharacteristicRemote::characteristicChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(GattDescriptorRemotePtr )>(_a, &GattCharacteristicRemote::gattDescriptorAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(QList<GattDescriptorRemotePtr> )>(_a, &GattCharacteristicRemote::descriptorsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(GattDescriptorRemotePtr )>(_a, &GattCharacteristicRemote::gattDescriptorRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(GattDescriptorRemotePtr )>(_a, &GattCharacteristicRemote::gattDescriptorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(const QString & )>(_a, &GattCharacteristicRemote::uuidChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(const QByteArray )>(_a, &GattCharacteristicRemote::valueChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(bool )>(_a, &GattCharacteristicRemote::writeAcquiredChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(bool )>(_a, &GattCharacteristicRemote::notifyAcquiredChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(bool )>(_a, &GattCharacteristicRemote::notifyingChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(QStringList )>(_a, &GattCharacteristicRemote::flagsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(quint16 )>(_a, &GattCharacteristicRemote::handleChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (GattCharacteristicRemote::*)(quint16 )>(_a, &GattCharacteristicRemote::MTUChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->ubi(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->uuid(); break;
        case 2: *reinterpret_cast<QByteArray*>(_v) = _t->value(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isWriteAcquired(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isNotifyAcquired(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isNotifying(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->flags(); break;
        case 7: *reinterpret_cast<quint16*>(_v) = _t->handle(); break;
        case 8: *reinterpret_cast<quint16*>(_v) = _t->MTU(); break;
        case 9: *reinterpret_cast<GattServiceRemotePtr*>(_v) = _t->service(); break;
        case 10: *reinterpret_cast<QList<GattDescriptorRemotePtr>*>(_v) = _t->descriptors(); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::GattCharacteristicRemote::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::GattCharacteristicRemote::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt24GattCharacteristicRemoteE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::GattCharacteristicRemote::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::GattCharacteristicRemote::characteristicChanged(GattCharacteristicRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::GattCharacteristicRemote::gattDescriptorAdded(GattDescriptorRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluezQt::GattCharacteristicRemote::descriptorsChanged(QList<GattDescriptorRemotePtr> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluezQt::GattCharacteristicRemote::gattDescriptorRemoved(GattDescriptorRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BluezQt::GattCharacteristicRemote::gattDescriptorChanged(GattDescriptorRemotePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BluezQt::GattCharacteristicRemote::uuidChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluezQt::GattCharacteristicRemote::valueChanged(const QByteArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BluezQt::GattCharacteristicRemote::writeAcquiredChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BluezQt::GattCharacteristicRemote::notifyAcquiredChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void BluezQt::GattCharacteristicRemote::notifyingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void BluezQt::GattCharacteristicRemote::flagsChanged(QStringList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void BluezQt::GattCharacteristicRemote::handleChanged(quint16 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void BluezQt::GattCharacteristicRemote::MTUChanged(quint16 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
