/****************************************************************************
** Meta object code from reading C++ file 'manager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../bluez-qt-6.25.0/src/manager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'manager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BluezQt7ManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto BluezQt::Manager::qt_create_metaobjectdata<qt_meta_tag_ZN7BluezQt7ManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BluezQt::Manager",
        "operationalChanged",
        "",
        "operational",
        "bluetoothOperationalChanged",
        "bluetoothBlockedChanged",
        "blocked",
        "adapterAdded",
        "AdapterPtr",
        "adapter",
        "adapterRemoved",
        "adapterChanged",
        "deviceAdded",
        "DevicePtr",
        "device",
        "deviceRemoved",
        "deviceChanged",
        "usableAdapterChanged",
        "allAdaptersRemoved",
        "initialized",
        "bluetoothOperational",
        "bluetoothBlocked",
        "usableAdapter",
        "adapters",
        "QList<AdapterPtr>",
        "devices",
        "QList<DevicePtr>",
        "rfkill",
        "BluezQt::Rfkill*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'operationalChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'bluetoothOperationalChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'bluetoothBlockedChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'adapterAdded'
        QtMocHelpers::SignalData<void(AdapterPtr)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'adapterRemoved'
        QtMocHelpers::SignalData<void(AdapterPtr)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'adapterChanged'
        QtMocHelpers::SignalData<void(AdapterPtr)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(DevicePtr)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(DevicePtr)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void(DevicePtr)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'usableAdapterChanged'
        QtMocHelpers::SignalData<void(AdapterPtr)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'allAdaptersRemoved'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'initialized'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'operational'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'bluetoothOperational'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'bluetoothBlocked'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'usableAdapter'
        QtMocHelpers::PropertyData<AdapterPtr>(22, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'adapters'
        QtMocHelpers::PropertyData<QList<AdapterPtr>>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'devices'
        QtMocHelpers::PropertyData<QList<DevicePtr>>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'rfkill'
        QtMocHelpers::PropertyData<BluezQt::Rfkill*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Manager, qt_meta_tag_ZN7BluezQt7ManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BluezQt::Manager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt7ManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt7ManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BluezQt7ManagerE_t>.metaTypes,
    nullptr
} };

void BluezQt::Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Manager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->operationalChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->bluetoothOperationalChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->bluetoothBlockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->adapterAdded((*reinterpret_cast<std::add_pointer_t<AdapterPtr>>(_a[1]))); break;
        case 4: _t->adapterRemoved((*reinterpret_cast<std::add_pointer_t<AdapterPtr>>(_a[1]))); break;
        case 5: _t->adapterChanged((*reinterpret_cast<std::add_pointer_t<AdapterPtr>>(_a[1]))); break;
        case 6: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<DevicePtr>>(_a[1]))); break;
        case 7: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<DevicePtr>>(_a[1]))); break;
        case 8: _t->deviceChanged((*reinterpret_cast<std::add_pointer_t<DevicePtr>>(_a[1]))); break;
        case 9: _t->usableAdapterChanged((*reinterpret_cast<std::add_pointer_t<AdapterPtr>>(_a[1]))); break;
        case 10: _t->allAdaptersRemoved(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(bool )>(_a, &Manager::operationalChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(bool )>(_a, &Manager::bluetoothOperationalChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(bool )>(_a, &Manager::bluetoothBlockedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(AdapterPtr )>(_a, &Manager::adapterAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(AdapterPtr )>(_a, &Manager::adapterRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(AdapterPtr )>(_a, &Manager::adapterChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(DevicePtr )>(_a, &Manager::deviceAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(DevicePtr )>(_a, &Manager::deviceRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(DevicePtr )>(_a, &Manager::deviceChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(AdapterPtr )>(_a, &Manager::usableAdapterChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::allAdaptersRemoved, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BluezQt::Rfkill* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isInitialized(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isOperational(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isBluetoothOperational(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isBluetoothBlocked(); break;
        case 4: *reinterpret_cast<AdapterPtr*>(_v) = _t->usableAdapter(); break;
        case 5: *reinterpret_cast<QList<AdapterPtr>*>(_v) = _t->adapters(); break;
        case 6: *reinterpret_cast<QList<DevicePtr>*>(_v) = _t->devices(); break;
        case 7: *reinterpret_cast<BluezQt::Rfkill**>(_v) = _t->rfkill(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setBluetoothBlocked(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BluezQt::Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BluezQt::Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BluezQt7ManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BluezQt::Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void BluezQt::Manager::operationalChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BluezQt::Manager::bluetoothOperationalChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BluezQt::Manager::bluetoothBlockedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BluezQt::Manager::adapterAdded(AdapterPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BluezQt::Manager::adapterRemoved(AdapterPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BluezQt::Manager::adapterChanged(AdapterPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BluezQt::Manager::deviceAdded(DevicePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BluezQt::Manager::deviceRemoved(DevicePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BluezQt::Manager::deviceChanged(DevicePtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void BluezQt::Manager::usableAdapterChanged(AdapterPtr _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void BluezQt::Manager::allAdaptersRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
