/****************************************************************************
** Meta object code from reading C++ file 'declarativedevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../bluez-qt-6.25.0/src/imports/declarativedevice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativedevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DeclarativeDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeDevice::qt_create_metaobjectdata<qt_meta_tag_ZN17DeclarativeDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeDevice",
        "QML.Element",
        "Device",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Device cannot be created",
        "deviceRemoved",
        "",
        "DeclarativeDevice*",
        "device",
        "deviceChanged",
        "nameChanged",
        "name",
        "friendlyNameChanged",
        "friendlyName",
        "remoteNameChanged",
        "remoteName",
        "deviceClassChanged",
        "deviceClass",
        "typeChanged",
        "BluezQt::Device::Type",
        "type",
        "appearanceChanged",
        "appearance",
        "iconChanged",
        "icon",
        "pairedChanged",
        "paired",
        "trustedChanged",
        "trusted",
        "blockedChanged",
        "blocked",
        "legacyPairingChanged",
        "legacyPairing",
        "rssiChanged",
        "rssi",
        "connectedChanged",
        "connected",
        "uuidsChanged",
        "uuids",
        "modaliasChanged",
        "modalias",
        "batteryChanged",
        "DeclarativeBattery*",
        "battery",
        "inputChanged",
        "DeclarativeInput*",
        "input",
        "mediaPlayerChanged",
        "DeclarativeMediaPlayer*",
        "mediaPlayer",
        "connectToDevice",
        "BluezQt::PendingCall*",
        "disconnectFromDevice",
        "connectProfile",
        "uuid",
        "disconnectProfile",
        "pair",
        "cancelPairing",
        "ubi",
        "address",
        "adapter",
        "DeclarativeAdapter*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(DeclarativeDevice *)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void(DeclarativeDevice *)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'friendlyNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'remoteNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'deviceClassChanged'
        QtMocHelpers::SignalData<void(quint32)>(18, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 19 },
        }}),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(BluezQt::Device::Type)>(20, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'appearanceChanged'
        QtMocHelpers::SignalData<void(quint16)>(23, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 24 },
        }}),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(25, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Signal 'pairedChanged'
        QtMocHelpers::SignalData<void(bool)>(27, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Signal 'trustedChanged'
        QtMocHelpers::SignalData<void(bool)>(29, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Signal 'blockedChanged'
        QtMocHelpers::SignalData<void(bool)>(31, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Signal 'legacyPairingChanged'
        QtMocHelpers::SignalData<void(bool)>(33, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Signal 'rssiChanged'
        QtMocHelpers::SignalData<void(qint16)>(35, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Short, 36 },
        }}),
        // Signal 'connectedChanged'
        QtMocHelpers::SignalData<void(bool)>(37, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Signal 'uuidsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(39, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 40 },
        }}),
        // Signal 'modaliasChanged'
        QtMocHelpers::SignalData<void(const QString &)>(41, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Signal 'batteryChanged'
        QtMocHelpers::SignalData<void(DeclarativeBattery *)>(43, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Signal 'inputChanged'
        QtMocHelpers::SignalData<void(DeclarativeInput *)>(46, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Signal 'mediaPlayerChanged'
        QtMocHelpers::SignalData<void(DeclarativeMediaPlayer *)>(49, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'connectToDevice'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(52, 8, QMC::AccessPublic, 0x80000000 | 53),
        // Slot 'disconnectFromDevice'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(54, 8, QMC::AccessPublic, 0x80000000 | 53),
        // Slot 'connectProfile'
        QtMocHelpers::SlotData<BluezQt::PendingCall *(const QString &)>(55, 8, QMC::AccessPublic, 0x80000000 | 53, {{
            { QMetaType::QString, 56 },
        }}),
        // Slot 'disconnectProfile'
        QtMocHelpers::SlotData<BluezQt::PendingCall *(const QString &)>(57, 8, QMC::AccessPublic, 0x80000000 | 53, {{
            { QMetaType::QString, 56 },
        }}),
        // Slot 'pair'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(58, 8, QMC::AccessPublic, 0x80000000 | 53),
        // Slot 'cancelPairing'
        QtMocHelpers::SlotData<BluezQt::PendingCall *()>(59, 8, QMC::AccessPublic, 0x80000000 | 53),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ubi'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'address'
        QtMocHelpers::PropertyData<QString>(61, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'friendlyName'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'remoteName'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'deviceClass'
        QtMocHelpers::PropertyData<quint32>(19, QMetaType::UInt, QMC::DefaultPropertyFlags, 5),
        // property 'type'
        QtMocHelpers::PropertyData<BluezQt::Device::Type>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'appearance'
        QtMocHelpers::PropertyData<quint16>(24, QMetaType::UShort, QMC::DefaultPropertyFlags, 7),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'paired'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'trusted'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'blocked'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'legacyPairing'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'rssi'
        QtMocHelpers::PropertyData<qint16>(36, QMetaType::Short, QMC::DefaultPropertyFlags, 13),
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'uuids'
        QtMocHelpers::PropertyData<QStringList>(40, QMetaType::QStringList, QMC::DefaultPropertyFlags, 15),
        // property 'modalias'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
        // property 'battery'
        QtMocHelpers::PropertyData<DeclarativeBattery*>(45, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 17),
        // property 'input'
        QtMocHelpers::PropertyData<DeclarativeInput*>(48, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 18),
        // property 'mediaPlayer'
        QtMocHelpers::PropertyData<DeclarativeMediaPlayer*>(51, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 19),
        // property 'adapter'
        QtMocHelpers::PropertyData<DeclarativeAdapter*>(62, 0x80000000 | 63, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeDevice, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17DeclarativeDeviceE[] = {
    QMetaObject::SuperData::link<BluezQt::Device::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject DeclarativeDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DeclarativeDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DeclarativeDeviceE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17DeclarativeDeviceE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DeclarativeDeviceE_t>.metaTypes,
    nullptr
} };

void DeclarativeDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<DeclarativeDevice*>>(_a[1]))); break;
        case 1: _t->deviceChanged((*reinterpret_cast<std::add_pointer_t<DeclarativeDevice*>>(_a[1]))); break;
        case 2: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->friendlyNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->remoteNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->deviceClassChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 6: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<BluezQt::Device::Type>>(_a[1]))); break;
        case 7: _t->appearanceChanged((*reinterpret_cast<std::add_pointer_t<quint16>>(_a[1]))); break;
        case 8: _t->iconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->pairedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->trustedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->blockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->legacyPairingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->rssiChanged((*reinterpret_cast<std::add_pointer_t<qint16>>(_a[1]))); break;
        case 14: _t->connectedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->uuidsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 16: _t->modaliasChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->batteryChanged((*reinterpret_cast<std::add_pointer_t<DeclarativeBattery*>>(_a[1]))); break;
        case 18: _t->inputChanged((*reinterpret_cast<std::add_pointer_t<DeclarativeInput*>>(_a[1]))); break;
        case 19: _t->mediaPlayerChanged((*reinterpret_cast<std::add_pointer_t<DeclarativeMediaPlayer*>>(_a[1]))); break;
        case 20: { BluezQt::PendingCall* _r = _t->connectToDevice();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 21: { BluezQt::PendingCall* _r = _t->disconnectFromDevice();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 22: { BluezQt::PendingCall* _r = _t->connectProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 23: { BluezQt::PendingCall* _r = _t->disconnectProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 24: { BluezQt::PendingCall* _r = _t->pair();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        case 25: { BluezQt::PendingCall* _r = _t->cancelPairing();
            if (_a[0]) *reinterpret_cast<BluezQt::PendingCall**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DeclarativeDevice* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DeclarativeDevice* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(DeclarativeDevice * )>(_a, &DeclarativeDevice::deviceRemoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(DeclarativeDevice * )>(_a, &DeclarativeDevice::deviceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(const QString & )>(_a, &DeclarativeDevice::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(const QString & )>(_a, &DeclarativeDevice::friendlyNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(const QString & )>(_a, &DeclarativeDevice::remoteNameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(quint32 )>(_a, &DeclarativeDevice::deviceClassChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(BluezQt::Device::Type )>(_a, &DeclarativeDevice::typeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(quint16 )>(_a, &DeclarativeDevice::appearanceChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(const QString & )>(_a, &DeclarativeDevice::iconChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(bool )>(_a, &DeclarativeDevice::pairedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(bool )>(_a, &DeclarativeDevice::trustedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(bool )>(_a, &DeclarativeDevice::blockedChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(bool )>(_a, &DeclarativeDevice::legacyPairingChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(qint16 )>(_a, &DeclarativeDevice::rssiChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(bool )>(_a, &DeclarativeDevice::connectedChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(const QStringList & )>(_a, &DeclarativeDevice::uuidsChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(const QString & )>(_a, &DeclarativeDevice::modaliasChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(DeclarativeBattery * )>(_a, &DeclarativeDevice::batteryChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(DeclarativeInput * )>(_a, &DeclarativeDevice::inputChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeDevice::*)(DeclarativeMediaPlayer * )>(_a, &DeclarativeDevice::mediaPlayerChanged, 19))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->ubi(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->address(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->friendlyName(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->remoteName(); break;
        case 5: *reinterpret_cast<quint32*>(_v) = _t->deviceClass(); break;
        case 6: *reinterpret_cast<BluezQt::Device::Type*>(_v) = _t->type(); break;
        case 7: *reinterpret_cast<quint16*>(_v) = _t->appearance(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->icon(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isPaired(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isTrusted(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isBlocked(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->hasLegacyPairing(); break;
        case 13: *reinterpret_cast<qint16*>(_v) = _t->rssi(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->isConnected(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->uuids(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->modalias(); break;
        case 17: *reinterpret_cast<DeclarativeBattery**>(_v) = _t->battery(); break;
        case 18: *reinterpret_cast<DeclarativeInput**>(_v) = _t->input(); break;
        case 19: *reinterpret_cast<DeclarativeMediaPlayer**>(_v) = _t->mediaPlayer(); break;
        case 20: *reinterpret_cast<DeclarativeAdapter**>(_v) = _t->adapter(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setTrusted(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setBlocked(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DeclarativeDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeclarativeDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeDevice::deviceRemoved(DeclarativeDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeDevice::deviceChanged(DeclarativeDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeDevice::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeDevice::friendlyNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeclarativeDevice::remoteNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DeclarativeDevice::deviceClassChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DeclarativeDevice::typeChanged(BluezQt::Device::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DeclarativeDevice::appearanceChanged(quint16 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DeclarativeDevice::iconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DeclarativeDevice::pairedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DeclarativeDevice::trustedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DeclarativeDevice::blockedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DeclarativeDevice::legacyPairingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DeclarativeDevice::rssiChanged(qint16 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DeclarativeDevice::connectedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DeclarativeDevice::uuidsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DeclarativeDevice::modaliasChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void DeclarativeDevice::batteryChanged(DeclarativeBattery * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void DeclarativeDevice::inputChanged(DeclarativeInput * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void DeclarativeDevice::mediaPlayerChanged(DeclarativeMediaPlayer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}
QT_WARNING_POP
